<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://modeltheme.com/
 * @since      1.0.0
 *
 * @package    Mtkb
 * @subpackage Mtkb/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Mtkb
 * @subpackage Mtkb/admin
 * @author     ModelTheme <support@modeltheme.com>
 */
class Mtkb_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Mtkb_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Mtkb_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/mt-knowledgebase-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Mtkb_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Mtkb_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/mt-knowledgebase-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	||-> CPT - [Knowledge Base]
	*/
	public function mtkb_register_knowledgebase_custom_post() {
	    register_post_type('mtkb-knowledgebase', array(
		    'label' => esc_html__('Knowledge Base','mtkb'),
		    'description' => '',
		    'public' => true,
		    'show_ui' => true,
		    'show_in_menu' => true,
		    'capability_type' => 'post',
		    'map_meta_cap' => true,
		    'hierarchical' => true,
		    'rewrite' => array('slug' => 'knowledgebase', 'with_front' => true),
		    'query_var' => true,
		    'menu_position' => '1',
		    'has_archive' => false,
		    'menu_icon' => 'dashicons-performance',
		    'supports' => array('title','editor','thumbnail','author','excerpt', 'comments'),
		    'labels' => array (
		        'name' => esc_html__('Knowledge Base','mtkb'),
		        'singular_name' => esc_html__('Knowledge','mtkb'),
		        'menu_name' => esc_html__('MT Knowledge Base','mtkb'),
		        'add_new' => esc_html__('Add Knowledge','mtkb'),
		        'add_new_item' => esc_html__('Add New Knowledge','mtkb'),
		        'edit' => esc_html__('Edit','mtkb'),
		        'edit_item' => esc_html__('Edit Knowledge','mtkb'),
		        'new_item' => esc_html__('New Knowledge','mtkb'),
		        'view' => esc_html__('View Knowledge','mtkb'),
		        'view_item' => esc_html__('View Knowledge','mtkb'),
		        'search_items' => esc_html__('Search Knowledge Base','mtkb'),
		        'not_found' => esc_html__('No Knowledge Found','mtkb'),
		        'not_found_in_trash' => esc_html__('No Knowledge Found in Trash','mtkb'),
		        'parent' => esc_html__('Parent Knowledge','mtkb'),
		        )
		    ) 
		); 
	}


	/**
	||-> CPT - [Knowledge Base] Taxonomy category
	*/
	public function mtkb_register_knowledgebase_category() {
	    
	    $labels = array(
	        'name'                       => esc_html_x( 'Categories', 'Taxonomy General Name', 'mtkb'  ),
	        'singular_name'              => esc_html_x( 'Categories', 'Taxonomy Singular Name', 'mtkb'  ),
	        'menu_name'                  => esc_html__( 'Categories', 'mtkb'  ),
	        'all_items'                  => esc_html__( 'All Items', 'mtkb'  ),
	        'parent_item'                => esc_html__( 'Parent Item', 'mtkb'  ),
	        'parent_item_colon'          => esc_html__( 'Parent Item:', 'mtkb'  ),
	        'new_item_name'              => esc_html__( 'New Item Name', 'mtkb'  ),
	        'add_new_item'               => esc_html__( 'Add New Item', 'mtkb'  ),
	        'edit_item'                  => esc_html__( 'Edit Item', 'mtkb'  ),
	        'update_item'                => esc_html__( 'Update Item', 'mtkb'  ),
	        'view_item'                  => esc_html__( 'View Item', 'mtkb'  ),
	        'separate_items_with_commas' => esc_html__( 'Separate items with commas', 'mtkb'  ),
	        'add_or_remove_items'        => esc_html__( 'Add or remove items', 'mtkb'  ),
	        'choose_from_most_used'      => esc_html__( 'Choose from the most used', 'mtkb'  ),
	        'popular_items'              => esc_html__( 'Popular Items', 'mtkb'  ),
	        'search_items'               => esc_html__( 'Search Items', 'mtkb'  ),
	        'not_found'                  => esc_html__( 'Not Found', 'mtkb'  ),
	    );

	    $args = array(
	        'hierarchical'      => true,
	        'labels'            => $labels,
	        'show_ui'           => true,
	        'show_admin_column' => true,
	        'show_in_nav_menus'          => true,
	        'query_var'         => true,
	        'rewrite'           => array( 'slug' => 'knowledgebase-category' ),
	        'public'            => true,
	    );

	    register_taxonomy( 'mtkb-knowledgebase-category', array( 'mtkb-knowledgebase' ), $args );
	}

	/**
	||-> CPT - [Knowledge Base] Taxonomy Tags
	*/
	public function mtkb_register_knowledgebase_tags() {
	    
	    $labels = array(
	        'name'                       => esc_html_x( 'Tags', 'Taxonomy General Name', 'mtkb'  ),
	        'singular_name'              => esc_html_x( 'Tags', 'Taxonomy Singular Name', 'mtkb'  ),
	        'menu_name'                  => esc_html__( 'Tags', 'mtkb'  ),
	        'all_items'                  => esc_html__( 'All Tags', 'mtkb'  ),
	        'parent_item'                => esc_html__( 'Parent Item', 'mtkb'  ),
	        'parent_item_colon'          => esc_html__( 'Parent Item:', 'mtkb'  ),
	        'new_item_name'              => esc_html__( 'New Item Name', 'mtkb'  ),
	        'add_new_item'               => esc_html__( 'Add New Item', 'mtkb'  ),
	        'edit_item'                  => esc_html__( 'Edit Item', 'mtkb'  ),
	        'update_item'                => esc_html__( 'Update Item', 'mtkb'  ),
	        'view_item'                  => esc_html__( 'View Item', 'mtkb'  ),
	        'separate_items_with_commas' => esc_html__( 'Separate items with commas', 'mtkb'  ),
	        'add_or_remove_items'        => esc_html__( 'Add or remove items', 'mtkb'  ),
	        'choose_from_most_used'      => esc_html__( 'Choose from the most used', 'mtkb'  ),
	        'popular_items'              => esc_html__( 'Popular Items', 'mtkb'  ),
	        'search_items'               => esc_html__( 'Search Items', 'mtkb'  ),
	        'not_found'                  => esc_html__( 'Not Found', 'mtkb'  ),
	    );
	    $args = array(
	        'labels'                     => $labels,
	        'hierarchical'               => false,
	        'public'                     => true,
	        'show_ui'                    => true,
	        'show_admin_column'          => true,
	        'show_in_nav_menus'          => true,
	        'show_tagcloud'              => true,
	        'rewrite'                    => array( 'slug' => 'knowledgebase-tag' ),
	    );
	    register_taxonomy( 'mtkb-knowledgebase-tags', array( 'mtkb-knowledgebase' ), $args );
	}

	/**
	||-> CPT - [Changelog]
	*/
	function mtkb_register_changelog_custom_post() {
	    register_post_type('mtkb-changelog', array(
            'label' => esc_html__('Changelog','mtkb'),

            'description' => '',
            'public' => true,
            'show_ui' => true,
            'show_in_menu' => true,
            'capability_type' => 'post',
            'map_meta_cap' => true,
            'hierarchical' => false,
            'publicly_queryable' => true,
            'rewrite' => array('slug' => 'changelog', 'with_front' => true),
            'query_var' => true,
            'menu_position' => '1',
            'menu_icon' => 'dashicons-format-aside',
            'supports' => array('title'),
            'labels' => array (
                'name' => esc_html__('Changelog','mtkb'),
                'singular_name' => esc_html__('Changelog','mtkb'),
                'menu_name' => esc_html__('MT Changelog','mtkb'),
                'add_new' => esc_html__('Add Changelog','mtkb'),
                'add_new_item' => esc_html__('Add New Changelog','mtkb'),
                'edit' => esc_html__('Edit','mtkb'),
                'edit_item' => esc_html__('Edit Changelog','mtkb'),
                'new_item' => esc_html__('New Changelog','mtkb'),
                'view' => esc_html__('View Changelog','mtkb'),
                'view_item' => esc_html__('View Changelog','mtkb'),
                'search_items' => esc_html__('Search Changelog','mtkb'),
                'not_found' => esc_html__('No Changelog Found','mtkb'),
                'not_found_in_trash' => esc_html__('No Changelog Found in Trash','mtkb'),
                'parent' => esc_html__('Parent Changelog','mtkb'),
                )
            ) 
        ); 
	}

	/**
	||-> CPT - [Portfolio]
	*/
	function mtkb_register_portfolio_custom_post() {
	    register_post_type('mtkb-portfolio', array(
            'label' => esc_html__('Portfolio','mtkb'),
            'description' => '',
            'public' => true,
            'show_ui' => true,
            'show_in_menu' => true,
            'capability_type' => 'post',
            'map_meta_cap' => true,
            'hierarchical' => false,
            'rewrite' => array('slug' => 'portfolio', 'with_front' => true),
            'query_var' => true,
            'menu_position' => '1',
            'menu_icon' => 'dashicons-performance',
            'supports' => array('title','editor','thumbnail','author','excerpt', 'comments'),
            'labels' => array (
                'name' => esc_html__('Portfolio','mtkb'),
                'singular_name' => esc_html__('Portfolio','mtkb'),
                'menu_name' => esc_html__('MT Portfolio','mtkb'),
                'add_new' => esc_html__('Add Portfolio','mtkb'),
                'add_new_item' => esc_html__('Add New Portfolio','mtkb'),
                'edit' => esc_html__('Edit','mtkb'),
                'edit_item' => esc_html__('Edit Portfolio','mtkb'),
                'new_item' => esc_html__('New Portfolio','mtkb'),
                'view' => esc_html__('View Portfolio','mtkb'),
                'view_item' => esc_html__('View Portfolio','mtkb'),
                'search_items' => esc_html__('Search Portfolio','mtkb'),
                'not_found' => esc_html__('No Portfolio Found','mtkb'),
                'not_found_in_trash' => esc_html__('No Portfolio Found in Trash','mtkb'),
                'parent' => esc_html__('Parent Portfolio','mtkb'),
                )
            ) 
        ); 
	}

	/**
	||-> CPT - [Portfolio] Category
	*/
	function mtkb_register_portfolio_category() {
	    
	    $labels = array(
	        'name'                       => esc_html_x( 'Categories', 'Taxonomy General Name', 'mtkb' ),
	        'singular_name'              => esc_html_x( 'Categories', 'Taxonomy Singular Name', 'mtkb' ),
	        'menu_name'                  => esc_html__( 'Categories', 'mtkb' ),
	        'all_items'                  => esc_html__( 'All Items', 'mtkb' ),
	        'parent_item'                => esc_html__( 'Parent Item', 'mtkb' ),
	        'parent_item_colon'          => esc_html__( 'Parent Item:', 'mtkb' ),
	        'new_item_name'              => esc_html__( 'New Item Name', 'mtkb' ),
	        'add_new_item'               => esc_html__( 'Add New Item', 'mtkb' ),
	        'edit_item'                  => esc_html__( 'Edit Item', 'mtkb' ),
	        'update_item'                => esc_html__( 'Update Item', 'mtkb' ),
	        'view_item'                  => esc_html__( 'View Item', 'mtkb' ),
	        'separate_items_with_commas' => esc_html__( 'Separate items with commas', 'mtkb' ),
	        'add_or_remove_items'        => esc_html__( 'Add or remove items', 'mtkb' ),
	        'choose_from_most_used'      => esc_html__( 'Choose from the most used', 'mtkb' ),
	        'popular_items'              => esc_html__( 'Popular Items', 'mtkb' ),
	        'search_items'               => esc_html__( 'Search Items', 'mtkb' ),
	        'not_found'                  => esc_html__( 'Not Found', 'mtkb' ),
	    );
	    $args = array(
	        'labels'                     => $labels,
	        'hierarchical'               => true,
	        'public'                     => true,
	        'show_ui'                    => true,
	        'show_admin_column'          => true,
	        'show_in_nav_menus'          => true,
	        'show_tagcloud'              => true,
	        'rewrite'                    => array( 'slug' => 'portfolio-category' ),
	    );
	    register_taxonomy( 'mtkb-portfolio-category', array( 'mtkb-portfolio' ), $args );
	}
	/**
	||-> CPT - [Portfolio] Tags
	*/
	function mtkb_register_portfolio_tags() {
	    
	    $labels = array(
	        'name'                       => esc_html_x( 'Tags', 'Taxonomy General Name', 'mtkb' ),
	        'singular_name'              => esc_html_x( 'Tags', 'Taxonomy Singular Name', 'mtkb' ),
	        'menu_name'                  => esc_html__( 'Tags', 'mtkb' ),
	        'all_items'                  => esc_html__( 'All Tags', 'mtkb' ),
	        'parent_item'                => esc_html__( 'Parent Item', 'mtkb' ),
	        'parent_item_colon'          => esc_html__( 'Parent Item:', 'mtkb' ),
	        'new_item_name'              => esc_html__( 'New Item Name', 'mtkb' ),
	        'add_new_item'               => esc_html__( 'Add New Item', 'mtkb' ),
	        'edit_item'                  => esc_html__( 'Edit Item', 'mtkb' ),
	        'update_item'                => esc_html__( 'Update Item', 'mtkb' ),
	        'view_item'                  => esc_html__( 'View Item', 'mtkb' ),
	        'separate_items_with_commas' => esc_html__( 'Separate items with commas', 'mtkb' ),
	        'add_or_remove_items'        => esc_html__( 'Add or remove items', 'mtkb' ),
	        'choose_from_most_used'      => esc_html__( 'Choose from the most used', 'mtkb' ),
	        'popular_items'              => esc_html__( 'Popular Items', 'mtkb' ),
	        'search_items'               => esc_html__( 'Search Items', 'mtkb' ),
	        'not_found'                  => esc_html__( 'Not Found', 'mtkb' ),
	    );
	    $args = array(
	        'labels'                     => $labels,
	        'hierarchical'               => false,
	        'public'                     => true,
	        'show_ui'                    => true,
	        'show_admin_column'          => true,
	        'show_in_nav_menus'          => true,
	        'show_tagcloud'              => true,
	        'rewrite'                    => array( 'slug' => 'portfolio-tag' ),
	    );
	    register_taxonomy( 'mtkb-portfolio-tags', array( 'mtkb-portfolio' ), $args );
	}

    //create "MT Knowledgebase" menu item page
	public function mtkb_add_menu_page() {
        if ( !empty ( $GLOBALS['admin_page_hooks']['mt_plugins'] ) ) {
            return;
        }

        add_menu_page(
            esc_html__("MT Plugins", "mtkb"),
            esc_html__("MT Plugins", "mtkb"),
            "NULL", "mt_plugins",
            "",
            "",
            3611
        );
    }

    public function mtkb_add_submenu_pages() {
        add_submenu_page(
            "mt_plugins",
             esc_html__("MT Knowledgebase", "mtkb"),
             esc_html__("MT Knowledgebase", "mtkb"),
            "manage_options",
            "mtkb_options",
            array($this, "mtkb_options_page")
        );
        //remove mt_plugins submenu page if wordpress created one
        remove_submenu_page( "mt_plugins", "mt_plugins" );
    }

    //create "MT knowledgebase Settings" settings page
    public function mtkb_options_page() {
        $this->mtkb_save_options();
        ?>
        <div class="wrap">
            <h2><?php esc_html__("MT knowledgebase Settings", "mtkb") ?></h2>
            <form class="scpotw-settings" method="post">
                <?php settings_fields( "mtkb_settings" ); ?>
                <?php do_settings_sections( "mtkb_settings" ); ?>
                <?php submit_button(); ?>
            </form>
        </div>
        <?php
    }

    // save the options values
    private function mtkb_save_options() {
        if (isset($_POST["mtkb_knowledgebase_enabled"])) {
            update_option("mtkb_knowledgebase_enabled", $_POST["mtkb_knowledgebase_enabled"]);
        }
        if (isset($_POST["mtkb_changelog_enabled"])) {
            update_option("mtkb_changelog_enabled", $_POST["mtkb_changelog_enabled"]);
        }
        if (isset($_POST["mtkb_portfolio_enabled"])) {
            update_option("mtkb_portfolio_enabled", $_POST["mtkb_portfolio_enabled"]);
        }
        if ( ! empty( $_POST['mtkb_date_format'] ) && isset( $_POST['mtkb_date_format_custom'] )
			&& '\c\u\s\t\o\m' === wp_unslash( $_POST['mtkb_date_format'] )
		) {
			$_POST['mtkb_date_format'] = $_POST['mtkb_date_format_custom'];
		}
		if (isset($_POST["mtkb_date_format"])) {
            update_option("mtkb_date_format", $_POST["mtkb_date_format"]);
        }
        if ( ! empty( $_POST['mtkb_time_format'] ) && isset( $_POST['mtkb_time_format_custom'] )
			&& '\c\u\s\t\o\m' === wp_unslash( $_POST['mtkb_time_format'] )
		) {
			$_POST['mtkb_time_format'] = $_POST['mtkb_time_format_custom'];
		}
		if (isset($_POST["mtkb_time_format"])) {
            update_option("mtkb_time_format", $_POST["mtkb_time_format"]);
        }
    }

    // yes/no dropdown for options
    public function render_yesno_field($args) {
        echo '<select id="'. esc_attr($args['name']) .'" name="'. esc_attr($args['name']) .'">';
        echo '<option value="no" ' . ($args['value'] == 'no' ? 'selected' : '') . '>' . esc_html__('No') . '</option>';
        echo '<option value="yes" ' . ($args['value'] == 'yes' ? 'selected' : '') . '>' . esc_html__('Yes') . '</option>';
        echo '</select>';
    }

    //custom date format
    public function custom_date_format($args) {
    	$date_formats = array_unique( apply_filters( 'date_formats', array( esc_html__( 'F j, Y' ), 'Y-m-d', 'm/d/Y', 'd/m/Y' ) ) );

		$custom = true;

		foreach ( $date_formats as $format ) {
			echo "\t<label><input type='radio' name='". esc_attr($args['name']) ."' value='" . esc_attr( $format ) . "'";
			if ( get_option( 'mtkb_date_format' ) === $format ) { // checked() uses "==" rather than "===".
				echo " checked='checked'";
				$custom = false;
			}
			echo ' /> <span class="date-time-text format-i18n">' . date_i18n( $format ) . '</span><code>' . esc_html( $format ) . "</code></label><br />\n";
		}

		echo '<label><input type="radio" name="'. esc_attr($args['name']) .'" id="'. esc_attr($args['name']) .'_custom_radio" value="\c\u\s\t\o\m"';
		checked( $custom );
		echo '/> <span class="date-time-text date-time-custom-text">' . esc_html__( 'Custom:' ) . '<span class="screen-reader-text"> ' . esc_html__( 'enter a custom date format in the following field', 'mtkb'  ) . '</span></span></label>' .
			'<label for="'. esc_attr($args['name']) .'_custom" class="screen-reader-text">' . esc_html__( 'Custom date format:', 'mtkb'  ) . '</label>' .
			'<input type="text" name="'. esc_attr($args['name']) .'_custom" id="'. esc_attr($args['name']) .'_custom" value="' . esc_attr( get_option( 'mtkb_date_format' ) ) . '" class="small-text" />' .
			'<br />' .
			'<p><strong>' . esc_html__( 'Preview:', 'mtkb'  ) . '</strong> <span class="example">' . date_i18n( get_option( 'mtkb_date_format' ) ) . '</span>' .
			"<span class='spinner'></span>\n" . '</p>';
    }

    //custom time format
    public function custom_time_format($args) {
    	$time_formats = array_unique( apply_filters( 'time_formats', array( esc_html__( 'g:i a' ), 'g:i A', 'H:i' ) ) );

		$custom = true;

		foreach ( $time_formats as $format ) {
			echo "\t<label><input type='radio' name='". esc_attr($args['name']) ."' value='" . esc_attr( $format ) . "'";
			if ( get_option( 'mtkb_time_format' ) === $format ) { // checked() uses "==" rather than "===".
				echo " checked='checked'";
				$custom = false;
			}
			echo ' /> <span class="date-time-text format-i18n">' . date_i18n( $format ) . '</span><code>' . esc_html( $format ) . "</code></label><br />\n";
		}

		echo '<label><input type="radio" name="'. esc_attr($args['name']) .'" id="'. esc_attr($args['name']) .'_custom_radio" value="\c\u\s\t\o\m"';
		checked( $custom );
		echo '/> <span class="date-time-text date-time-custom-text">' . esc_html__( 'Custom:' ) . '<span class="screen-reader-text"> ' . esc_html__( 'enter a custom time format in the following field', 'mtkb'  ) . '</span></span></label>' .
			'<label for="'. esc_attr($args['name']) .'_custom" class="screen-reader-text">' . esc_html__( 'Custom time format:', 'mtkb'  ) . '</label>' .
			'<input type="text" name="'. esc_attr($args['name']) .'_custom" id="'. esc_attr($args['name']) .'_custom" value="' . esc_attr( get_option( 'mtkb_time_format' ) ) . '" class="small-text" />' .
			'<br />' .
			'<p><strong>' . esc_html__( 'Preview:', 'mtkb'  ) . '</strong> <span class="example">' . date_i18n( get_option( 'mtkb_time_format' ) ) . '</span>' .
			"<span class='spinner'></span>\n" . '</p>';
    }

    //plugin pannel options
    public function mtkb_register_settings() {

        register_setting( "mtkb_settings", "mtkb_knowledgebase_enabled" );
        register_setting( "mtkb_settings", "mtkb_changelog_enabled" );
        register_setting( "mtkb_settings", "mtkb_portfolio_enabled" );
        register_setting( "mtkb_settings", "mtkb_date_format" );
        add_settings_section(
            "mtkb_settings",
            esc_html__("Settings", "mtkb"),
            null,
            "mtkb_settings"
        );

        add_settings_field(
            "mtkb_knowledgebase_enabled",
            esc_html__("Enable MT Knowledgebase", "mtkb"),
            array($this, "render_yesno_field"),
            "mtkb_settings",
            "mtkb_settings",
            [
                "name" => "mtkb_knowledgebase_enabled",
                "value" => !empty($_POST["mtkb_knowledgebase_enabled"]) ? $_POST["mtkb_knowledgebase_enabled"] : get_option("mtkb_knowledgebase_enabled")
            ]
        );

        add_settings_field(
            "mtkb_changelog_enabled",
            esc_html__("Enable MT Changelog", "mtkb"),
            array($this, "render_yesno_field"),
            "mtkb_settings",
            "mtkb_settings",
            [
                "name" => "mtkb_changelog_enabled",
                "value" => !empty($_POST["mtkb_changelog_enabled"]) ? $_POST["mtkb_changelog_enabled"] : get_option("mtkb_changelog_enabled")
            ]
        );

        add_settings_field(
            "mtkb_portfolio_enabled",
            esc_html__("Enable MT Portfolio", "mtkb"),
            array($this, "render_yesno_field"),
            "mtkb_settings",
            "mtkb_settings",
            [
                "name" => "mtkb_portfolio_enabled",
                "value" => !empty($_POST["mtkb_portfolio_enabled"]) ? $_POST["mtkb_portfolio_enabled"] : get_option("mtkb_portfolio_enabled")
            ]
        );

        add_settings_field(
            "mtkb_date_format",
            esc_html__("Custom MT Date Format", "mtkb"),
            array($this, "custom_date_format"),
            "mtkb_settings",
            "mtkb_settings",
            [
                "name" => "mtkb_date_format",
                "value" => !empty($_POST["mtkb_date_format"]) ? $_POST["mtkb_date_format"] : get_option("mtkb_date_format")
            ]
        );

        add_settings_field(
            "mtkb_time_format",
            esc_html__("Custom MT Time Format", "mtkb"),
            array($this, "custom_time_format"),
            "mtkb_settings",
            "mtkb_settings",
            [
                "name" => "mtkb_time_format",
                "value" => !empty($_POST["mtkb_time_format"]) ? $_POST["mtkb_time_format"] : get_option("mtkb_time_format")
            ]
        );
    }

	/* Custom metabox for mtkb-portfolio */
    function mtkb_portfolio_add_meta_box() {

        add_meta_box( 'page-options', esc_html__( 'Portfolio Options', 'mtk' ), array($this, 'mtkb_portfolio_show_metabox_callback'), 'mtkb-portfolio', 'side', 'high' );

    }

	/**
	 * Prints the box content.
	 * 
	 * @param WP_Post $post The object for the current post/page.
	 */
    function mtkb_portfolio_show_metabox_callback( $post ) {

        // Add an nonce field so we can check for it later.
        wp_nonce_field( 'page_options_nonce', 'page_nonce' );

        /*
         * Use get_post_meta() to retrieve an existing value
         * from the database and use the value for the form.
         */

        $external_link_url          = get_post_meta( $post->ID, 'mtkb-external-link-url-field'  , true );
        $external_link_text         = get_post_meta( $post->ID, 'mtkb-external-link-text-field' , true );
        $knowledgebase_category     = get_post_meta( $post->ID, 'mtkb-knowledgebase-category'   , true );
        $changelog_id        		= get_post_meta( $post->ID, 'mtkb-changelog-id'       , true );

        $html = '';

        $html .='
        <div class="mtkb-portfolio-metabox">
			<div class="metabox-page">
        		<label for="mtkb-external-link-text-field">'.esc_html__( 'External Link Text:', 'mtkb' ).'</label>
        		<input type="text" name="mtkb-external-link-text-field" value="' . esc_attr( $external_link_text ) . '"/>
        	</div>

        	<div class="metabox-page">
        		<label for="mtkb-external-link-url-field">'.esc_html__( 'External Link URL:', 'mtkb' ).'</label>
        		<input type="text" name="mtkb-external-link-url-field" value="' . esc_attr( $external_link_url ) . '"/>
        	</div>

        	<div class="metabox-page">
       			<label for="mtkb-knowledgebase-category">'.esc_html__( 'Knowledgebase Category:', 'mtkb' ).'</label>
	        	<select name="mtkb-knowledgebase-category" class="postform">
	        		<option value="">Select Category</option>';
			        // categories array
					$mtkb_knowledgebase_categories = get_terms('mtkb-knowledgebase-category');
			        if ($mtkb_knowledgebase_categories) {
			          	foreach ( $mtkb_knowledgebase_categories as $term ) {
			            	$html .='<option value="'.esc_attr($term->term_id).'" '.($knowledgebase_category == $term->term_id ? 'selected="selected"' : '').'>'.esc_html($term->name).'</option>';
			          	}
			        }
		        $html .='</select>
	        </div>

        	<div class="metabox-page">
        		<label for="mtkb-changelog-id">'.esc_html__( 'Changelog:', 'mtkb' ).'</label>
		        <select name="mtkb-changelog-id" class="postform">
	        		<option value="">Select Changelog</option>';
		        	// categories array
		        	$mtkb_changelog_args = array(
		        		'post_type' => 'mtkb-changelog',
	        		);
					$mtkb_changelogs_query = new Wp_Query($mtkb_changelog_args);
					if( $mtkb_changelogs_query->have_posts() ){
						while ( $mtkb_changelogs_query->have_posts() ) {
							$mtkb_changelogs_query->the_post();
			            	$html .='<option value="'.esc_attr($term->term_id).'" '.($changelog_id == get_the_ID() ? 'selected="selected"' : '').'>'.esc_html(get_the_title()).'</option>';
						}
					}
        		$html .='</select>
        	</div>
        	<div style="clear:both"></div>
        </div>';

        echo $html;
    }

	/**
	 * When the post is saved, saves our custom data.
	 *
	 * @param int $post_id The ID of the post being saved.
	 */
    function mtkb_portfolio_save_page_meta_box( $post_id ) {

        /*
         * We need to verify this came from our screen and with proper authorization,
         * because the save_post action can be triggered at other times.
         */

        // Check if our nonce is set.
        if ( ! isset( $_POST['page_nonce'] ) ) {
            return;
        }

        // Verify that the nonce is valid.
        if ( ! wp_verify_nonce( $_POST['page_nonce'], 'page_options_nonce' ) ) {
            return;
        }

        // If this is an autosave, our form has not been submitted, so we don't want to do anything.
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
            return;
        }

        // Check the user's permissions.
        if ( isset( $_POST['post_type'] ) && 'mtkb-portfolio' == $_POST['post_type'] ) {
            if ( ! current_user_can( 'edit_post', $post_id ) ) {
                return;
            }

        }

        /* OK, it's safe for us to save the data now. */
        // Update the meta field in the database.

        if(isset( $_POST['mtkb-external-link-text-field'] 	))
	        update_post_meta( $post_id, 'mtkb-external-link-text-field'     , sanitize_text_field( $_POST['mtkb-external-link-text-field'] ) );
	    if(isset( $_POST['mtkb-external-link-url-field'] 	))
	        update_post_meta( $post_id, 'mtkb-external-link-url-field'      , sanitize_text_field( $_POST['mtkb-external-link-url-field'] ) );
        if(isset( $_POST['mtkb-knowledgebase-category'] ))
	        update_post_meta( $post_id, 'mtkb-knowledgebase-category'    	, sanitize_text_field( $_POST['mtkb-knowledgebase-category'] ) );
        if(isset( $_POST['mtkb-knowledgebase-category'] ))
	        update_post_meta( $post_id, 'mtkb-changelog-id'     		, sanitize_text_field( $_POST['mtkb-changelog-id'] ) );
    }
	/** 
	* Hook in and add a metabox to add fields to taxonomy terms 
	*/ 
	function mtkb_changelog_repeatable_wysiwyg() { 
	  

		$fields_group = new_cmb2_box( array(
		    'id'           => 'mtkb_changelog_group',
		    'title'        => esc_html__( 'Changelog Fields', 'mtkb' ),
		    'object_types' => array( 'mtkb-changelog' ),
		) );

		// $fields_group_id is the field id string, so in this case: 'yourprefix_group_demo'
		$fields_group_id = $fields_group->add_field( array(
		    'id'          => 'mtkb_changelog_group',
		    'type'        => 'group',
		    'options'     => array(
		          'group_title'    => esc_html__( 'Version', 'mtkb' ), // {#} gets replaced by row number
		          'add_button'     => esc_html__( 'Add New Version', 'mtkb' ),
		          'remove_button'  => esc_html__( 'Delete Version', 'mtkb' ),
		          'sortable'       => true,
		          'closed'      => true, // true to have the groups closed by default
		          'remove_confirm' => esc_html__( 'Are you sure you want to delete this Version?', 'mtkb' ), // Performs confirmation before removing group.
		    ),
		) );

		$fields_group->add_group_field( $fields_group_id, array(
		    'name'    => __( 'Version Number (ex: 1.0)', 'mtkb' ),
		    'desc'    => __( 'Current version', 'mtkb' ),
		    'id'      => 'mtkb_changelog_version',
		    'type'    => 'text',
		    'default' => ''
		) );
		$fields_group->add_group_field( $fields_group_id, array(
		    'name'    => __( 'Version Release Date', 'mtkb' ),
		    'desc'    => __( 'Date when the theme version has been released', 'mtkb' ),
		    'id'      => 'mtkb_changelog_published_at',
		    'type' => 'text_date_timestamp',
		    'default' => ''
		) );
		$fields_group->add_group_field( $fields_group_id, array(
		    'name'       => esc_html__( 'Version Changes', 'mtkb' ),
		    'id'         => 'mtkb_changelog_content',
		    'type'       => 'wysiwyg',
		) );
	} 

}
