<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://modeltheme.com/
 * @since      1.0.0
 *
 * @package    Mtkb
 * @subpackage Mtkb/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Mtkb
 * @subpackage Mtkb/public
 * @author     ModelTheme <support@modeltheme.com>
 */
class Mtkb_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Mtkb_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Mtkb_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( 'bootstrap-grid', plugin_dir_url( __FILE__ ) . 'css/bootstrap-grid.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'fontello', plugin_dir_url( __FILE__ ) . 'css/fontello.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/mt-knowledgebase-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Mtkb_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Mtkb_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/mt-knowledgebase-public.js', array( 'jquery' ), $this->version, false );
		wp_localize_script($this->plugin_name, 'ajax_search', array(
	        'url' => admin_url('admin-ajax.php'),
	    ));
	    wp_localize_script($this->plugin_name, 'ajax_var', array(
	        'url' => admin_url('admin-ajax.php'),
	        'nonce' => wp_create_nonce('ajax-nonce')
	    ));

	    wp_enqueue_script( 'filters-mixitup.min', plugin_dir_url( __FILE__ ) . '/js/filters-mixitup.min.js', array('jquery'), '1.0.0', true );
        wp_enqueue_script( 'filters-main', plugin_dir_url( __FILE__ ) . '/js/filters-main.js', array('jquery'), '1.0.0', true );


	}

    function mtkb_kses_allowed_html($tags, $context) {
      	switch($context) {
	        case 'html': 
	            $tags = array( 
	                'div' => array(
	                    'class' => array(),
	                ),
	                'i' => array(
	                    'class' => array(),
	                ),
	                'span' => array(
	                    'class' => array(),
	                ),
	                'a'	  => array(
	                	'class'	=> array(),
	                	'data-post_id'	=>array(),
	                ),
	            );
	            return $tags;
	        break;
	        
	        case 'link': 
	            $tags = array( 
	                'a' => array(
	                    'href' => array(),
	                    'class' => array(),
	                    'title' => array(),
	                    'target' => array(),
	                    'rel' => array(),
	                    'data-commentid' => array(),
	                    'data-postid' => array(),
	                    'data-belowelement' => array(),
	                    'data-respondelement' => array(),
	                    'data-replyto' => array(),
	                    'aria-label' => array(),
	                ),
	                'img' => array(
	                    'src' => array(),
	                    'alt' => array(),
	                    'style' => array(),
	                    'height' => array(),
	                    'width' => array(),

	                ),
	            );
	            return $tags;
	        break;

	        case 'icon':
	            $tags = array(
	                'i' => array(
	                    'class' => array(),
	                ),
	            );
	            return $tags;
	        break;

	        case 'categories': 
	            $tags = array( 
	                'a' => array(
	                    'href' => array(),
	                    'class' => array(),
	                    'title' => array(),
	                    'target' => array(),
	                    'rel' => array(),
	                ),
	            );
	            return $tags;
	        break;
	        
	        default: 
	            return $tags;
        }
    }

	/* Filter the single_template with our custom function knowledge base*/
	function mtkb_template_from_directory_knowledgebase($template) {
	    global $wp_query, $post;
	    /* Checks for single template by post type */
	    if ( $post->post_type == 'mtkb-knowledgebase') {
	    	if( is_single() ){
			    $theme_files = 'mt-knowledgebase/knowledgebase/single-mtkb-knowledgebase.php';
		        $exists_in_theme = locate_template( $theme_files, false );
				if ( $exists_in_theme != '' ) {
			        // Try to locate in theme first
			        $template = $exists_in_theme;
			    } else {
			        if ( file_exists( plugin_dir_path( __FILE__ ) . 'templates/mtkb-knowledgebase/single-mtkb-knowledgebase.php' ) ) {
			            $template = plugin_dir_path( __FILE__ ) . 'templates/mtkb-knowledgebase/single-mtkb-knowledgebase.php';
			        }
				}
	    	} elseif (is_tax('mtkb-knowledgebase-category') || is_tax('mtkb-knowledgebase-tags') || ($wp_query->is_search) && $post->post_type == 'mtkb-knowledgebase' ) {
	    		$theme_files = 'mt-knowledgebase/knowledgebase/taxonomy-mtkb-knowledgebase.php';
		        $exists_in_theme = locate_template( $theme_files, false );
		        if ( $exists_in_theme != '' ) {
		            // Try to locate in theme first
		            $template = $exists_in_theme;
		        } else {
		            if(file_exists(trailingslashit(plugin_dir_path( __FILE__ ) . 'templates/mtkb-knowledgebase/taxonomy-mtkb-knowledgebase.php'))) {
		                $template = trailingslashit(plugin_dir_path( __FILE__ ) . 'templates/mtkb-knowledgebase/taxonomy-mtkb-knowledgebase.php');
		            }else {
		                $template = plugin_dir_path( __FILE__ ) . 'templates/mtkb-knowledgebase/taxonomy-mtkb-knowledgebase.php';
		            }
		        }
	    	}

	    } 
	    return $template;
	}

	function mtkb_taxonomy_template_from_directory_portfolio($template){
    	// is a specific custom taxonomy being shown?
		$custom_post_type = 'mtkb-portfolio';
		$taxonomy_array = array('mtkb-portfolio-category', 'mtkb-portfolio-tags');

		$theme_files = 'mt-knowledgebase/portfolio/taxonomy-mtkb-portfolio.php';
        $exists_in_theme = locate_template( $theme_files, false );

		foreach ($taxonomy_array as $taxonomy_single) {
			if ( is_tax($taxonomy_single) ) {
				if ( $exists_in_theme != '' ) {
		            // Try to locate in theme first
		            $template = $exists_in_theme;
		        } else {
		            if(file_exists(trailingslashit(plugin_dir_path( __FILE__ ) . 'templates/mtkb-portfolio/taxonomy-mtkb-portfolio.php'))) {
		                $template = trailingslashit(plugin_dir_path( __FILE__ ) . 'templates/mtkb-portfolio/taxonomy-mtkb-portfolio.php');
		            }else {
		                $template = plugin_dir_path( __FILE__ ) . 'templates/mtkb-portfolio/taxonomy-mtkb-portfolio.php';
		            }
		        }
			}

	    }
	    return $template;

	}

	/* Filter the single_template with our custom function knowledge base*/
	function mtkb_single_template_from_directory_portfolio($single) {
	    global $wp_query, $post;
	    $theme_files = 'mt-knowledgebase/portfolio/single-mtkb-portfolio.php';
        $exists_in_theme = locate_template( $theme_files, false );
	    /* Checks for single template by post type */
	    if ( $post->post_type == 'mtkb-portfolio' && is_single() ) {
			if ( $exists_in_theme != '' ) {
		        // Try to locate in theme first
		        $single = $exists_in_theme;
		    } else {
		        if ( file_exists( plugin_dir_path( __FILE__ ) . 'templates/mtkb-portfolio/single-mtkb-portfolio.php' ) ) {
		            $single = plugin_dir_path( __FILE__ ) . 'templates/mtkb-portfolio/single-mtkb-portfolio.php';
		        }
			}
	    }
	    return $single;
	}




	function mtkb_taxonomy_template_from_directory_changelog($template){
    // is a specific custom taxonomy being shown?
		global $wp_query, $post;
		$custom_post_type = '';
		$theme_files = 'mt-knowledgebase/changelogs/taxonomy-mtkb-changelog.php';
        $exists_in_theme = locate_template( $theme_files, false );

	    if ( $post->post_type == 'mtkb-changelog') {
	    	if( is_single() ){
			    $theme_files = 'mt-knowledgebase/changelogs/taxonomy-mtkb-changelog.php';
		        $exists_in_theme = locate_template( $theme_files, false );
				if ( $exists_in_theme != '' ) {
			        // Try to locate in theme first
			        $template = $exists_in_theme;
			    } else {
			        if ( file_exists( plugin_dir_path( __FILE__ ) . 'templates/mtkb-changelog/single-mtkb-changelog.php' ) ) {
			            $template = plugin_dir_path( __FILE__ ) . 'templates/mtkb-changelog/single-mtkb-changelog.php';
			        }
				}
	    	}
	    }
	    return $template;
	}

	/**
	 * Add a sidebar for knowledgebase.
	 */
	function mtkb_register_sidebar() {
	    register_sidebar( array(
	        'name'          => esc_html__( 'Knowledgebase Sidebar', 'textdomain' ),
	        'id'            => 'sidebar-knowledgebase',
	        'description'   => esc_html__( 'Widgets in this area will be shown on Knowledgebase Category Page and Knowledgebase Single Page.', 'mtkb' ),
	        'before_widget' => '<div id="%1$s" class="widget %2$s">',
	        'after_widget'  => '</div>',
	        'before_title'  => '<h2 class="widgettitle">',
	        'after_title'   => '</h2>',
	    ) );
	}

	/**
	||-> Shortcode: Knowledge Grid Container
	*/
	function mtkb_shortcode_knowledge_grid_container($params,  $content = NULL) {
	    extract( 
	    	shortcode_atts( 
		        array(
		            'additional_class'			=>'',
		    	), $params 
		    ) 
		);

	    $html = '';       

	    $html .= '<div class="mtkb_knowledge-grid-container '.esc_attr($additional_class).'">';
	    	$html .= '<div class="mtkb_knowledge-grid row">';

	        	$html .= do_shortcode($content);
	        
	    	$html .= '</div>';
		$html .= '</div>';

		return $html;
	}
	/**
	||-> Shortcode: Knowledgebase List
	*/
	function mtkb_shortcode_list($params, $content) {
	    extract( shortcode_atts( 
	        array(
	            'category_id'			=>'',
	            'number'              	=>'',
	            'columns'			  	=>'',
	            'version'				=>'',
		        'additional_class'      =>'',
	        ), $params )
	    );

	    $args_knowledgebase = array(
			'posts_per_page'   => $number,
			'post_type'        => 'mtkb-knowledgebase',
			'tax_query' => array(
				array(
			    	'taxonomy' => 'mtkb-knowledgebase-category',
			    	'field' => 'term_id',
			    	'terms' => $category_id
			  	)
			),
			'post_status'      => 'publish' 
		);  

	    $query_knowledgebase = new WP_Query( $args_knowledgebase);
	    $category_title = get_term( $category_id )->name;
	    $category_slug = get_term( $category_id )->slug;
	    $icon = '';
	    if($version == '2') {
	    	$icon = '<i class="fontello-icon-dot-circled" aria-hidden="true"></i>';
	    }
	    if(!$columns  && $columns =="") {
	    	$columns = "col-md-4";
	    }

	    $html = '';
	    $html .= '<div class="'.esc_attr($columns).'">';
		    $html .= '<div class="mtkb_knowledge-list'.esc_attr($version).' '.esc_attr($additional_class).'">';
				$html .= '<div class="heading-submenu">';
					$html .= '<h3 class="heading">';
					if($version == '2') {
						$html .= '<a class="heading-link" href="'.esc_url( get_category_link( ($category_id) ) ).'">';
							$html .= $icon . esc_html($category_title) .'
						</a>';
					} elseif( $version == '1' ) {
						$html .= $category_title;
					}
						
					$html .= '</h3>';
					$html .= '<ul class="submenu">';
					if($query_knowledgebase->have_posts()) {
						while ($query_knowledgebase->have_posts()) {
							$query_knowledgebase->the_post();
							$html.='<li class="post_title">
									<a href="'.esc_url( get_permalink( get_the_ID() ) ).'" title="'.esc_attr(get_the_title()).'">'.esc_html(get_the_title()).'</a>
								</li>';      
						}
						wp_reset_postdata();
					}
					$html .= '</ul>';
				$html .= '</div>';

				if($version == '2') {
					$knowledgebase_count = $query_knowledgebase->found_posts;
					$html .='<a class="count-link" href="'.esc_url( get_category_link( ($category_id) ) ).'">'.sprintf( esc_html(_n( '%s Article in this category', '%s Articles in this category', $knowledgebase_count, 'mtkb' )), number_format_i18n( $knowledgebase_count ) ).'</a>';
				} elseif ($version == '1') {
					$html .= '<a class="count-link" href="'.esc_url( get_category_link( ($category_id) ) ).'">' .esc_html__('View all', 'mtkb').' <i class="fontello-icon-right" aria-hidden="true"></i></a>';
				}
		    $html .= '</div>';
	    $html .= '</div>';

	    return $html;
	}

	/**
	||-> Shortcode: Knowledgebase Search
	*/
	function mtkb_shortcode_ico_search($params, $content) {
	    extract( shortcode_atts( 
	        array(
	            'additional_class'           => '',
	            'placeholder'				 => '',
	        ), $params ) );

	    if(!$placeholder || $placeholder == ''){
	    	$placeholder = esc_html__('Search Knowledge Base...', 'mtkb');
	    }

	    $html = '';
	    $html .= '<div class="mtkb-knowledge-search '.esc_attr($additional_class).' ">
	                <form role="search" method="get" id="mtkb_knowledge_searchform" autocomplete="off" class="clearfix" action="'.esc_url(get_site_url()).'">
	                  <input type="hidden" name="post_type" value="mtkb-knowledgebase">
	                  <input placeholder="'.esc_attr__( $placeholder, 'mtkb').'" type="text" name="s" id="mtkb_keyword" onkeyup="fetch()">
	                  <button type="submit" id="mtkb_searchsubmit"> <i class="fontello-icon-search"></i></button>
	                </form>
	                <div id="mtkb_datafetch"></div> 
	            </div>';
	    return $html;
	}

	// the ajax function
	function mtkb_search_data_fetch(){
		if ( $_POST['mtkb_keyword'] == null ) { 
			die(); 
		}

	    $query_knowledgebase = new WP_Query( 
	    	array( 
	    		'post_type'=> 'mtkb-knowledgebase',
	    		'post_per_page' =>  -1,
	    		's' => esc_attr( $_POST['mtkb_keyword'] ) 
	    	) 
	    );

	    if( $query_knowledgebase->have_posts() ) : ?>
	        <ul class="mtkb_search-result">           
	            <?php while( $query_knowledgebase->have_posts() ): 
	            	$query_knowledgebase->the_post();  
	            	$post_type = get_post_type_object( get_post_type() );?>                
	                <li>
	                	<a href="<?php echo esc_url( post_permalink() ); ?>"><?php the_title();?></a>
	                </li>             
	            <?php endwhile; ?>
	        </ul>       
	        <?php wp_reset_postdata();  
	    endif;
	    die();
	}

	/**
	||-> Shortcode: knowledgebase archive list
	*/
	function mtkb_shortcode_knowledge_a_z( $params, $content = null ) {
	  
		extract( shortcode_atts( 
		    array(
	            'additional_class'			=>'',
	        ), $params ) 
		);
	  	$sorted = array();

	  	$args_knowledgebase = array(
	    	'posts_per_page'	=> -1,
	      	'orderby'          => 'title',
	      	'order'            => 'ASC',
	      	'post_type'        => 'mtkb-knowledgebase',
	      	'post_status'      => 'publish' 
	    );
	  
	  	$query_knowledgebase = new WP_Query( $args_knowledgebase );
	  	if ($query_knowledgebase->have_posts()) {
	  		$sorted_list = array();
	  		while ($query_knowledgebase->have_posts()) {
	  			$query_knowledgebase->the_post();
	  			$name = get_the_title();
	  			$char = $name[0];
	  			$id = get_the_ID();
	  			$existing_ids = array();
		    	if ( array_key_exists ( $char , $sorted_list ) ) {
		      		$existing_ids = $sorted_list[ $char ];
		      		if(!array_key_exists ( $id , $existing_ids ))
		      			array_push($existing_ids, $id);
		      		$sorted_list[ $char ] = $existing_ids;
		    	}
		    	else
		    		$sorted_list[ $char ] = array($id);
	  		}
	  		ksort( $sorted_list );
		  	wp_reset_postdata();
	  	}

	  	$knowledgebase_list = '';
	  	$knowledgebase_list = '<div class="mtkb-knowledgebase-shortcode-archive-ordered '.esc_attr($additional_class).'">';
	    	foreach ( $sorted_list as $character => $knowledges_id ) {
	      	$knowledgebase_list .= '<span class="mtkb-knowledgebase-first-letter">' . esc_html($character) . '</span></br>';
	      	$knowledgebase_list .= '<ul class="mtkb-knowledgebase-list">';
	      	foreach ( $knowledges_id as $knowledge_id ) {
	        	$knowledgebase_list .= '<li><a href="'.esc_url(get_the_permalink($knowledge_id)).'" title="'. esc_attr(get_the_title($knowledge_id)) .'">'. esc_html(get_the_title($knowledge_id)) .'</a></li>';
	      	}
	      	$knowledgebase_list .= '</ul>';
	    }
	  	$knowledgebase_list .= '</div> ';

	  	return $knowledgebase_list;
	}

	/**
	||-> Shortcode: Knowledgebase Accordion
	*/
	function mtkb_shortcode_categories_accordion($params,  $content = NULL) {
	    extract( shortcode_atts( 
	        array(
				'heading_title'			=>'',
			    'additional_class'      =>'',
	            'is_active'           	=>'',
	            'number'              	=>'',
	        ), $params 
	    ) );

	    $knowledgebase_categories = get_terms('mtkb-knowledgebase-category');
    	$html = '';       
	  	$html .= '<div class="mtkb-knowledgebase-accordion '.esc_attr($additional_class).'">';
	    	$html .= '<h3 class="mtkb-heading-title">'.esc_html($heading_title).'</h3>';
	    	$html .= '<div class="knowledge-accordion">';
	      		$html .= '<ul id="mtkb-accordion" class="mtkb-accordion">';
	      		global $post;
	      		
			    foreach ($knowledgebase_categories  as $category) {
			    	$category_id = $category->term_id;
					$args_knowledges = array(
			            'posts_per_page'   => $number,
			            'orderby'          => 'post_date',
			            'order'            => 'DESC',
			            'post_type'        => 'mtkb-knowledgebase',
			            'tax_query' 	   => array(
			            	array(
					    		'taxonomy'		=> 'mtkb-knowledgebase-category',
					    		'field' 		=> 'term_id',
					    		'terms' 		=> $category_id
					  		)
			            ),
			                'post_status'   => 'publish' 
			        ); 
			        
			    	$knowledges = new WP_Query($args_knowledges);
				    $category_name = get_term( $category_id )->name;

				    $open_accordion = '';
				    if($is_active == $category_id && !is_tax('mtkb-knowledgebase-category') && !is_single()) {
				        $open_accordion = 'default open';
				    } elseif (is_tax('mtkb-knowledgebase-category', $category_id)) {
				    	$open_accordion = 'default open';
				    } elseif ( is_single( get_the_ID() ) && get_post_type(get_the_ID()) == 'mtkb-knowledgebase' ) {
				    	$knowledgebase_categories =  get_the_terms( get_the_ID(), 'mtkb-knowledgebase-category' );
				    	foreach ($knowledgebase_categories as $knowledgebase_category) {
				    		if($category_id == $knowledgebase_category->term_id) {
				    			$open_accordion = 'default open';
				    		}
				    		break;
				    	}
					}

	        		$html .= '<li class="mtkb-knowledgebase-category '.esc_attr($open_accordion).' '.esc_attr($additional_class).'">';
				        $html .= '<div class="link">'. esc_html($category_name) .'<i class="fontello-icon-right-open"></i></div>';
					    	$html .= '<ul class="submenu">';
					    	if ($knowledges->have_posts()) {
				    			while ($knowledges->have_posts()) {
				    				$knowledges->the_post();
				    				$currentClass = ( is_single( get_the_ID() ) == true ) ? " current_post": "";
				    				$html.='<li class="post_title '.esc_attr($currentClass).'"><a href="'.esc_url(get_permalink()).'" title="'. esc_attr(get_the_title()) .'">'.esc_html(get_the_title($knowledges->ID)).'</a></li>';   
				    			}
							  	wp_reset_postdata();
				    		}
				    		$html .= '</ul>';
				    $html .= '</li>';
    			}
		      	$html .= '</ul>';
	    	$html .= '</div>';
	  	$html .= '</div>';

	  	return $html;

	}

	/**
	||-> Shortcode: Knowledge Category
	*/
	function mtkb_shortcode_categories_grid($params, $content = NULL) {

	    extract( shortcode_atts( 
	        array(
	            'hide_empty'			=> '',
	            'number'           		=> '',
	            'additional_class'      => '',
	            'columns'      			=> '',
	            'style'      			=> '',
	        ), $params 
	    ) );

	    if(!$hide_empty || $hide_empty == '') {
	    	$hide_empty = true;
	    }

	    $kb_categories = get_terms(array(
            'taxonomy' => 'mtkb-knowledgebase-category',
            'hide_empty' => $hide_empty,
        ));

        $html = '';
        $html .= '<div class="row mtkb-knowledgebase-categories-grid '.esc_attr($additional_class).'">';

	        foreach ($kb_categories as $kb_category) {
	            $category_id = $kb_category->term_id;
	            $knowledgebase_args = array(
	                'posts_per_page'   => $number,
	                'post_type'        => 'mtkb-knowledgebase',
	                'tax_query' => array(
	                    array(
	                        'taxonomy' => 'mtkb-knowledgebase-category',
	                        'field' => 'term_id',
	                        'terms' => $category_id
	                    )
	                ),
	                'post_status'      => 'publish' 
	            );
	            if(!$style || $style == '') {
	            	$style = '2';
	            }

	            $knowledgebase_query = new WP_Query($knowledgebase_args);
	            $knowledgebase_count = $knowledgebase_query->found_posts;

	            $html .='<div class="'.esc_attr($columns).'">
	                <div class="mtkb_knowledge-list'.esc_attr($style).'">
	                    <div class="heading-submenu">
	                        <h3 class="heading">
	                            <a class="heading-link" href="'.esc_url( get_category_link( ($category_id) ) ).'">
	                                <i class="fontello-icon-dot-circled" aria-hidden="true"></i>'.esc_html($kb_category->name).'
	                            </a>
	                        </h3>
	                        <ul class="submenu">';
		                        if($knowledgebase_query->have_posts()) {
		                        	while ($knowledgebase_query->have_posts()) {
		                        		$knowledgebase_query->the_post(); 
	                                    $html .= '<li class="post_title">
	                                        <a href="'.esc_url( get_permalink() ).'">'.esc_html( get_the_title() ).'</a>
	                                    </li>';
		                        	}
		                        	wp_reset_postdata();
		                        }
		                    $html .= '</ul>
		                </div>';
		                if($style == '2') {
			                $html .='<a class="count-link" href="'.esc_url( get_category_link( ($category_id) ) ).'">'.sprintf( esc_html(_n( '%s Article in this category', '%s Articles in this category', $knowledgebase_count, 'mtkb' )), number_format_i18n( $knowledgebase_count ) ).'</a>';
		                } elseif($style == '1') {
							$html .= '<a class="count-link" href="'.esc_url( get_category_link( ($category_id) ) ).'">' .esc_html__('View all', 'mtkb').' <i class="fontello-icon-right" aria-hidden="true"></i></a>';		                	
		                }

		            $html .='</div>
		        </div>';
		    }

	    $html .= '</div>';
	    return $html;
	}


	/**
	||-> Shortcode: Changelog List Container
	*/
	function mtkb_shortcode_changelog_container( $params, $content = NULL ) {

		extract( 
			shortcode_atts( 
		        array(
	            	'additional_class'			=> '',
		            'title'            			=> '',
		        ), $params 
		    ) 
	    );

		$html ='';
	    $html .= '<div class="mtkb-knowledgebase-changelog-container '.esc_attr($additional_class).'">';
	    	$html .= '<h3 class="changelog-title">'.esc_html($title).'</h3>';
	    	$html .= '<ul class="mtkb-knowledgebase-changelog-list">';

	        	$html .= do_shortcode($content);
	        
	    	$html .= '</ul>';
		$html .= '</div>';

		return $html;
	}

	/**
	||-> Shortcode: Changelog List Container Item New
	*/
	function mtkb_shortcode_changelog_container_item( $params, $content = NULL ) {
		extract( 
			shortcode_atts( 
		        array(
		            'additional_class'			=> '',
		            'item_type'            		=> '',
		        ), $params 
		    ) 
	    );
		$icon = '<i class="fontello-icon-plus"></i>';

	    if($item_type == "new") {
	    	$icon = '<i class="fontello-icon-plus"></i>';
	    } elseif($item_type == "update") {
	    	$icon = '<i class="fontello-icon-arrows-cw"></i>';
	    } elseif($item_type == "improvement") {
	    	$icon = '<i class="fontello-icon-ok"></i>';
	    } elseif($item_type == "fix") {
	    	$icon = '<i class="fontello-icon-link"></i>';
	    }

		$html ='';
    	$html .= '<li class="mtkb_changelog_list_item '.esc_attr($item_type).' '.esc_attr($additional_class).'">';
        	$html .= wp_kses($icon, 'icon') . esc_html($content);
    	$html .= '</li>';

		return $html;
	}
	/**
	||-> Shortcode: Single Changelog
	*/
	function mtkb_shortcode_single_changelog( $params, $content = NULL ) {
		extract( 
			shortcode_atts( 
		        array(
		            'additional_class'          => '',
		            'changelog_id'            	=> '',
		            'changelog_version'        	=> '',
		        ), $params 
		    ) 
	    );

        $changelog_atts = array(
            'number'        =>1,
            'post_type'     =>'mtkb-changelog',
            'p'             => $changelog_id,
        );

        $changelog_query = new \WP_Query($changelog_atts);

        ob_start();

        if($changelog_query->have_posts()) {
            while ( $changelog_query->have_posts()) {
                $changelog_query->the_post(); 
                $changelog_gorup = get_post_meta(get_the_ID(), 'mtkb_changelog_group', true);

				foreach ($changelog_gorup as $changelog) {
					if($changelog['mtkb_changelog_version'] == $changelog_version) { ?>
		                <article id="version-<?php echo esc_attr( $changelog['mtkb_changelog_version'] ); ?>" class="mtkb-knowledgebase-changelog-article '<?php echo esc_attr($additional_class); ?>"> 
		                    <div class="mtkb-knowledgebase-changelog-entry">
		                        <div class="row">
		                            <div class="col-md-4 mtkb-knowledgebase-changelog-metadata">
		                                <h3 class="changelog-title"><?php echo esc_html__('Version v', 'mtkb') . esc_html( $changelog['mtkb_changelog_version'] ); ?></h2>
		                                <time><i class="fontello-icon-clock"></i><?php echo esc_html__('Date: ','mtkb'); the_time(get_option('mtkb_date_format'), $changelog['mtkb_changelog_published_at']);?></time>
		                            </div>
		                            <div class="col-md-8">
		                                <div class="mtkb-knowledgebase-changelog-content">
		                                    <?php echo do_shortcode($changelog['mtkb_changelog_content']); ?>
		                                </div>
		                            </div>
		                        </div>
		                    </div>
		                </article>
					<?php }
				}

            }
            wp_reset_postdata();
        }

	    $output_string = ob_get_contents();
		ob_end_clean();
		return $output_string;
	}

	/**
	||-> Shortcode: MT-knowledgebase category accordion
	*/
	function mtkb_shortcode_knowledgebase_category_accordion( $params, $content = NULL ) {
		extract( 
			shortcode_atts( 
		        array(
		            'number'            	=> '',
		            'category_id'			=> '',
		            'additional_class'		=> '',
		        ), $params 
		    ) 
	    );

	    $Knowledgebase_atts = array(
	    	'number' 			=>$number,
	    	'post_type'        	=> 'mtkb-knowledgebase',
            'tax_query'			=> array(
            	array(
		    		'taxonomy' 	=> 'mtkb-knowledgebase-category',
		    		'field' 	=> 'term_id',
		    		'terms' 	=> $category_id
		  		)
            ),
                'post_status'   => 'publish' 
	    );

	    $Knowledgebase_query = new WP_Query($Knowledgebase_atts);

	    $html = '';
	    $html .='<div class="mtkb-knowledgebase-category_acordion alignwide '.esc_attr($additional_class).'">';
		    $html .= '<ul class="mtkb-knowledgebase-category_acordion_list">';

			    if($Knowledgebase_query->have_posts()) {
			    	while ( $Knowledgebase_query->have_posts()) {
			    		$Knowledgebase_query->the_post(); 

			    		$excerpt = get_the_excerpt();
						$excerpt = substr($excerpt, 0, 250);
						$result = substr($excerpt, 0, strrpos($excerpt, ' '));

			    		$html .= '<li class="mtkb-knowledgebase-item"> 
			    			<div class="mtkb-knowledgebase-title-holder">
			    				<h3 class="mtkb-knowledgebase-title">'.esc_html( get_the_title() ).'<i class="fontello-icon-right-open"></i>
			    				</h3>
			    			</div>
			    			<div class="mtkb-knowledgebase-content-holder">
			    				<p>'.esc_html( $result ).'... <a class="mtkb-knowledgebase-read-more" href="'.esc_url( get_the_permalink() ).'">'.esc_html__('read more', 'mtkb').'</a></p>
			    			</div>
		                </li>';
			    	}
			    	wp_reset_postdata();
			    }

		    $html .= '</ul>';
	    $html .= '</div>';

	    return $html;
	}

	/**
	||-> Shortcode: FAQs
	*/
	function mtkb_shortcode_faqs_container( $params, $content = NULL ) {

		extract( 
			shortcode_atts( 
		        array(
		            'additional_class'           => '',
		        ), $params 
		    ) 
	    );
		
	    $html = '';
	    $html .='<div class="mtkb-knowledgebase-faqs-container '.esc_attr($additional_class).'">';
		    $html .= '<ul class="mtkb-knowledgebase-faqs">';

		    	$html .= do_shortcode($content);
			    
		    $html .= '</ul>';
	    $html .= '</div>';

	    return $html;
	}

	/**
	||-> Shortcode: FAQs item
	*/
	function mtkb_shortcode_faqs_item( $params, $content = NULL ) {
		extract( 
			shortcode_atts( 
		        array(
		            'title'           	 	=> '',
		            'additional_class'		=> '',
		        ), $params 
		    ) 
	    );

	    $html = '';

		$html .= '<li class="mtkb-knowledgebase-faqs-item '.esc_attr($additional_class).'"> 
			<div class="faq-title-holder">
				<h3 class="faq-title">'.esc_html( $title ).'<i class="fontello-icon-right-open"></i></h3>
			</div>
			<div class="faq-content-holder">
				<p>'.esc_html( $content ).'</p>
			</div>
        </li>';
	    return $html;
	}


	/*
	 * Love/Unlove a post
	 * Hooked into wp_ajax_ above to save post IDs when button clicked.
	 */

	function mtkb_love_post() {
	    
	    // Security measures for the ajax call
	    
	    $nonce = $_POST['_wpnonce'];
	    if (!wp_verify_nonce($nonce, 'ajax-nonce'))
	        die("Security check has not passed.");
	    
	    if (isset($_POST['mtkb_love_post'])) {
	        
	        // Get the post ID of the clicked button's post and the current user's ID
	        
	        $post_id = $_POST['post_id'];
	        // Get the count of loves for the particular post
	        $post_mt_love_count = get_post_meta($post_id, "mtkb_love_count", true);
	        if (is_user_logged_in()) {
	        	$user_id = get_current_user_id();
	        
		        
		        
		        // Get the users who loved the post
		        
		        $postmetadata_userIDs = get_post_meta($post_id, "mtkb_user_loved");
		        
		        $users_loved = array();
		        
		        if (count($postmetadata_userIDs) != 0) {
		            $users_loved = $postmetadata_userIDs[0];
		        }
		        
		        if (!is_array($users_loved))
		            $users_loved = array();
		        
		        $users_loved['User_ID-' . $user_id] = $user_id;
		        
		        if (!$this->mtkb_already_loved($post_id)) {
		            
		            // Love
		            update_post_meta($post_id, "mtkb_user_loved", $users_loved);
		            update_post_meta($post_id, "mtkb_love_count", ++$post_mt_love_count);
		            
		            $response['count']   = $post_mt_love_count;
		            $response['message'] = '<i class="fontello-icon-heart"></i>';
		        }
		        
		        else {
		            
		            // Unlove
		            $uid_key = array_search($user_id, $loved_users); // find the key
		            unset($loved_users[$uid_key]); // remove from array
		            
		            update_post_meta($post_id, "mtkb_user_loved", $loved_users); // Remove user ID from post meta
		            update_post_meta($post_id, "mtkb_love_count", --$post_mt_love_count); // -1 count post meta
		            
		            $response['count']   = $post_mt_love_count;
		            $response['message'] = '<i class="fontello-icon-heart-empty"></i>';
		      
		        }
	        } elseif(!is_user_logged_in()) {
	        	$response['count']   = $post_mt_love_count;
		        $response['message'] = '<i class="fontello-icon-heart-empty"></i><span class="mtkb-knowledgebase-nolike">'.esc_html__('You have to login or register to like posts!', 'mtkb').'</span>';
	        }
	        
	        
	        
	        wp_send_json($response);
	    }
	}

	/*
	/ Function to display the love button on the front-end below every post
	*/

	function mtkb_display_love_button() {
	    // Total counts for the post
	    $post_id = get_the_ID();
	    $love_count = get_post_meta($post_id, "mtkb_love_count", true);
	    $count      = (empty($love_count) || $love_count == "0") ? '0' : $love_count;
	    
	    // Prepare button html
	    if(is_user_logged_in() && get_post_type() == 'mtkb-knowledgebase') {
	    	if (!$this->mtkb_already_loved($post_id)) {
	        	$html = '<div class="mtkb-knowledgebase-lb-wrapper"><a href="#" data-post_id="' . esc_attr($post_id) . '"> <i class="fontello-icon-heart-empty"></i></a><span>' . esc_html($count) . ' </span></div>';
	    	} else {
	        	$html = '<div class="mtkb-knowledgebase-lb-wrapper mtkb-knowledgebase-lb-loved"><a href="#" data-post_id="' .esc_attr($post_id) . '"> <i class="fontello-icon-heart"></i></a><span> ' . esc_html($count) . '</span></div>';
	    	}
	    } elseif(!is_user_logged_in() && get_post_type() == 'mtkb-knowledgebase') {
	    	if($count != '0') {
	    		$html = '<div class="mtkb-knowledgebase-lb-wrapper mtkb-knowledgebase-lb-loved"><a href="#" data-post_id="' .esc_attr($post_id) . '"> <i class="fontello-icon-heart-empty"></i></a><span> ' . esc_html($count) . '</span></div>';
	    	} elseif($count == '0') {
	    		$html = '<div class="mtkb-knowledgebase-lb-wrapper"><a href="#" data-post_id="' . esc_attr($post_id) . '"> <i class="fontello-icon-heart-empty"></i></a><span>' . esc_html($count) . ' </span></div>';
	    	}
	    }
	    
	    return $html;
	}

	/* 
	 * Function to check whether the user who clicks the love button already loved the post
	 */

	function mtkb_already_loved($post_id) {

	    $user_id = get_current_user_id();
	    $postmetadata_userIDs = get_post_meta($post_id, "mtkb_user_loved", false);
	    $users_loved = array();
	    
	    if (count($postmetadata_userIDs) != 0) {
	        $users_loved = $postmetadata_userIDs[0];
	    }
	    if (!is_array($users_loved))
	        $users_loved = array();
	    
	    if (in_array($user_id, $users_loved)) {
	        return true;
	    } else {
	        return false;
	    }
	}

	/*
	 * Set post views count using post meta
	 */
	function mtkb_views_count() {
	    $countKey = 'mtkb_post_views_count';
	    $postID = get_the_ID();
	    if((get_post_type() == 'mtkb-knowledgebase' || get_post_type() == 'mtkb-portfolio') && is_singular() ) {
	    	$count = get_post_meta($postID, $countKey, true);
		    if($count==''){
		        $count = 0;
		        update_post_meta($postID, $countKey, '0');
		    }else{
		        $count++;
		        update_post_meta($postID, $countKey, $count);
		    }
	    }
	}

	function mtkb_display_views_cout() {
	    $post_id = get_the_ID();
	    $views_count = get_post_meta($post_id, "mtkb_post_views_count", true);

	    $html ='<div class="mtkb-knowledgebase-views-counter"><i class="fontello-icon-eye"></i><span>'.esc_html($views_count).'</span></div>';

	    return $html;
	}

	/**
	 * Most liked/viewed/recent knowledges shortcode
	 */
	function mtkb_shortcode_most($params, $content=NULL) {
		extract( 
	    	shortcode_atts( 
		        array(
		            'number'				=> '',
		            'type'					=> '',
		            'columns'				=> '',
		            'additional_class'		=> '',
		            'button_text'			=> '',
					'button_url'			=> '',
		    	), $params 
		    ) 
		);
		$post_type = 'mtkb-knowledgebase';
		if($type == 'most_liked') {
			$Knowledgebase_atts = array(
				'post_per_page'	 => $number,
				'post_type'  => $post_type,
				'meta_key'   => 'mtkb_love_count',
			    'orderby'    => 'meta_value_num',
			    'order'      => 'DESC',
			);
		} elseif($type == 'most_viewed') {
			$Knowledgebase_atts = array(
				'post_per_page'	 => $number,
				'post_type'  => $post_type,
				'meta_key'   => 'mtkb_post_views_count',
			    'orderby'    => 'meta_value_num',
			    'order'      => 'DESC',
			);

		} elseif($type == 'most_recent') {
			$Knowledgebase_atts = array(
				'post_per_page'	=> $number,
				'post_type' => $post_type,
	            'orderby' 	=> 'date',
	            'order'   	=> 'DESC',
			);
		}

		if($button_text == '' || !$button_text) {
			$button_text = "View More";
		}
		if($button_url == '' || !$button_url) {
			$button_url = "#";
		}

		$Knowledgebase_list = new WP_Query($Knowledgebase_atts);
		$html = '';
		if ($Knowledgebase_list->have_posts()) {
			$html .= '<div class="'.esc_attr($columns).' '.esc_attr($additional_class).'">';
			    $html .= '<div class="mtkb_knowledge-list-most mtkb_knowledge-list">';
					$html .= '<div class="heading-submenu">';
						$html .= '<h3 class="heading">';
							$count = $Knowledgebase_list->found_posts;
							$count_text = sprintf( esc_html(_n( '%s Article', '%s Articles', $count, 'mtkb' )), number_format_i18n( $count ) );
							if($type == 'most_liked') {
								$html .= '<i class="fontello-icon-star"></i>' . esc_html__('Most Liked', 'mtkb') .'<span class="mtkb-knowledgebase-count">'. esc_html($count_text).'</span>';
							} elseif( $type == 'most_viewed' ) {
								$html .= '<i class="fontello-icon-eye"></i>' . esc_html__('Most Viewed', 'mtkb') .'<span class="mtkb-knowledgebase-count">'. esc_html($count_text).'</span>';
							} elseif( $type == 'most_recent' ) {
								$html .= '<i class="fontello-icon-doc-inv"></i>' . esc_html__('Most Recent', 'mtkb') .'<span class="mtkb-knowledgebase-count">'. esc_html($count_text).'</span>';
							}
						$html .= '</h3>';
						$html .= '<ul class="submenu">';
							while ($Knowledgebase_list->have_posts()) {
								$Knowledgebase_list->the_post();
								$html.='<li class="post_title">
									<a href="'.esc_url( get_permalink( get_the_ID() ) ).'">'.esc_html(get_the_title()).'</a>
								</li>';      
							}
							wp_reset_postdata();
						$html .= '</ul>';
					$html .= '</div>';
					$html .= '<a class="count-link" href="'.esc_url($button_url).'">'.esc_html($button_text).' <i class="fontello-icon-right" aria-hidden="true"></i></a>';
			    $html .= '</div>';
		    $html .= '</div>';
		}
		return $html;
	}
	function mtkb_portfolio_thumbnail_size() {
	    add_image_size( 'mtkb-portfolio-thumpnail', 300, 300 ); // (cropped)
	    add_image_size( 'mtkb-portfolio-single-image', 600, 600 ); // (cropped)
	}

	/**
	||-> Shortcode: MTKB Portfolio Filters
	*/
	function mtkb_portfolio_shortcode_filters($params, $content=NULL) {
	  	extract( shortcode_atts( 
	    	array(
	      	'number'             =>'',
	      	'searchfilter'       =>'',
	      	'tagsfilter'         =>'',
	      	'categoryfilter'     =>'',
	      	'additional_class'	 =>'',
	      	'columns'			 =>'',
	    	), $params 
	    ) );
	  	$mtkb_portfolios_args = array(
	    	'posts_per_page'   => $number,
	    	'post_type'        => 'mtkb-portfolio',
	    	'post_status'      => 'publish' 
	  	); 
	  	$portfolio_query 	= new WP_Query($mtkb_portfolios_args);
	  	$categories 		= get_terms( 'mtkb-portfolio-category', array('orderby' => 'count','order' => 'DESC', 'hide_empty' => 1) );
	  	$tags 				= get_terms( 'mtkb-portfolio-tags', array('orderby' => 'count','order' => 'DESC', 'hide_empty' => 1) );
	  	
	  	$html = '';
	  	$html .= '<div class="mtkb-portfolio-shortcode-container portfolio-posts-list portfolio-posts-list2">';
		    $html .= '<div>';
		      	$html .= '<main class="cd-main-content">';
	                $html .= '<div class="cd-filter">';
		          		$html .= '<form>';
		            		$html .= '<div class="row">';

		            			if($searchfilter == 'search_on') {
			                		$html .= '<div class="search-on col-md-4">';
			                  			$html .= '<div class="">';
			                    			$html .= '<div class="cd-filter-block">';
			                      				$html .= '<div class="cd-filter-content">';
			                        				$html .= '<input type="search" placeholder="'.esc_html__('Search Portfolio...', 'mtkb').'">';
			                      				$html .= '</div>';
			                    			$html .= '</div>';
			                  			$html .= '</div>';
			                		$html .= '</div>';
			                	}

		              			$html .= '<div class="col-md-4">';
		              				if($categoryfilter == 'category_on') {
		                  				$html .= '<div class="cd-filter-block">';
		                    				$html .= '<div class="cd-filter-content">';
		                      					$html .= '<div class="cd-select cd-filters">';
		                        					$html .= '<select class="filter" name="select-category" id="select-category">';
		                          						$html .= '<option value="">'.esc_html__('Categories', 'mtkb').'</option>';
		                          						foreach($categories as $category){
		                            						$html .= '<option value=".'.esc_attr($category->slug).'">'.esc_html($category->name).' ('.esc_html($category->count).')</option>';            
		                          						}
		                          					$html .= '</select>';
		                      					$html .= '</div>';                  
		                    				$html .= '</div>';  
		                  				$html .= '</div>';  
		                			}
		              			$html .= '</div>';
		              			$html .= '<div class="col-md-4">'; 
		                			if($tagsfilter == 'tags_on') {
		                  				$html .= '<div class="cd-filter-block">';
		                   					$html .= '<div class="cd-filter-content">';
		                      					$html .= '<div class="cd-select cd-filters">';
		                        					$html .= '<select class="filter" name="select-tag" id="select-tag">';
		                          						$html .= '<option value="">'.esc_html__('Tags', 'mtkb').'</option>';
	                          							foreach($tags as $tag){
	                            							$html .= '<option value=".'.esc_attr($tag->slug).'">'.esc_html($tag->name).' ('.esc_html($tag->count).')</option>';                
	                          							}
		                          					$html .= '</select>';
		                      					$html .= '</div>';                  
		                    				$html .= '</div>';  
		                  				$html .= '</div>';  
		                			}
		              			$html .= '</div>';  
		            		$html .= '</div>';
		          		$html .= '</form>';
	        		$html .= '</div>';
		        	$html .= '<section class="cd-gallery mtkb-portfolio-container">';
		          		$html .= '<ul class="row">';
		          		if($portfolio_query->have_posts()){
		          			while ($portfolio_query->have_posts()) {
		          				$portfolio_query->the_post();
		          				$theme_link 				= get_permalink(get_the_ID());
			              		$thumbnail_src 				= wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'mtkb-portfolio-thumpnail' );
				              	$portfolio_category_list 	= wp_get_post_terms(get_the_ID(), 'mtkb-portfolio-category');
				              	$portfolio_category_slugs 	= implode(' ',wp_list_pluck($portfolio_category_list,'slug'));
		              			$portfolio_tag_list 		= wp_get_post_terms(get_the_ID(), 'mtkb-portfolio-tags');
		              			$portfolio_tag_slugs 		= implode(' ',wp_list_pluck($portfolio_tag_list,'slug'));
		              			$all_categories 			= get_the_term_list( get_the_ID(), 'mtkb-portfolio-category', '', ' / ' );


		              			$sticky_class = '';

		              			if ( is_sticky(get_the_ID()) ) {
		                  			$sticky_class = 'is-sticky';
		              			}
		                                                               
		              			$html.='<li class="'.esc_attr($sticky_class).' mix '.esc_attr($portfolio_category_slugs).' '.esc_attr($portfolio_tag_slugs).' '.esc_attr( get_the_title() ).' '.esc_attr($columns).'" style="display:none;">
		                			<div class="mtkb-portfolio-col post '.esc_attr($sticky_class).'">';
		                  				$html.='<article class="mtkb-portfolio-single">';
		                    				$html.='<div class="mtkb-portfolio-singleitem mtkb-box">';
		                      					$html.='<a href="'.esc_url($theme_link).'" title="'. esc_attr( get_the_title( get_the_ID() ) ) .'"><img class="mtkb-portfolio-image" src="'.esc_url($thumbnail_src[0]).'" alt="'.esc_attr( get_the_title( get_the_ID() ) ).'"></a>';
		                      					$html.='<div class="mtkb-portfolio-details">';
		                        					$html.='<a href="'.esc_url($theme_link).'" title="'. esc_attr( get_the_title( get_the_ID() ) ) .'">
		                        						<h3 class="mtkb-portfolio-name">'. esc_html( get_the_title( get_the_ID() ) ) .'</h3>
		                        					</a>';
		                        					$html.='<h4 class="mtkb-portfolio-category">'.wp_kses($all_categories, 'categories').'</h4>';
		                        					$html.='<div class="mtkb-portfolio-metas">';
							                            $html.='<a href="'.esc_url($theme_link).'" title="'.esc_attr( get_the_title( get_the_ID() ) ).'" class="mtkb-portfolio-button">'.esc_html__("View More", 'mtkb').' </a>';
				                        			$html.='</div>';
				                      			$html.='</div>';              
				                    		$html.='</div>';
				                  		$html.='</article>';            
				                	$html.='  </div>
				              	</li>';
		          			}
		          			wp_reset_postdata();
		          		}
				        $html .= '</ul>';
				        $html .= '<div class="cd-fail-message">'.esc_html__('No results found', 'mtkb').'</div>';
				    $html .= '</section>';
				$html .= '</main>';
			$html .= '</div>';
		$html .= '</div>';
		return $html;
	}

		/**
	||-> Shortcode: MTKB Portfolio Category
	*/
	function mtkb_portfolio_shortcode_category($params, $content=NULL) {
	  	extract( shortcode_atts( 
	    	array(
	      	'number'             =>'',
	      	'category_id'       =>'',
	      	'additional_class'	 =>'',
	      	'columns'			 =>'',
	    	), $params 
	    ) );
	  	$mtkb_portfolio_args = array(
	    	'posts_per_page'   => $number,
	    	'post_type'        => 'mtkb-portfolio',
	    	'tax_query' => array(
				array(
			    	'taxonomy' => 'mtkb-portfolio-category',
			    	'field' => 'term_id',
			    	'terms' => $category_id
			  	)
			),
	    	'post_status'      => 'publish' 
	  	); 
	  	$portfolio_query 	= new WP_Query($mtkb_portfolio_args);
	  	
	  	$html = '';
	    $html .= '<div class="mtkb-portfolio-container '.esc_attr($additional_class).'">';
	      	$html .= '<div class="row">';
          		if($portfolio_query->have_posts()){
          			while ($portfolio_query->have_posts()) {
          				$portfolio_query->the_post();
          				$theme_link 				= get_permalink(get_the_ID());
	              		$thumbnail_src 				= wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'mtkb-portfolio-thumpnail' );
              			$all_categories 			= get_the_term_list( get_the_ID(), 'mtkb-portfolio-category', '', ' / ' );


              			$sticky_class = '';

              			if ( is_sticky(get_the_ID()) ) {
                  			$sticky_class = 'is-sticky';
              			}
                                                               
              			$html.='<div class="'.esc_attr($sticky_class).' '.esc_attr( get_the_title() ).' '.esc_attr($columns).' mtkb-portfolio-col">';
              				$html.='<article class="mtkb-portfolio-single">';
                				$html.='<div class="mtkb-portfolio-singleitem mtkb-box">';
                  					$html.='<a href="'.esc_url($theme_link).'" title="'. esc_attr( get_the_title( get_the_ID() ) ) .'"><img class="mtkb-portfolio-image" src="'.esc_url($thumbnail_src[0]).'" alt="'.esc_attr( get_the_title( get_the_ID() ) ).'"></a>';
                  					$html.='<div class="mtkb-portfolio-details">';
                    					$html.='<a href="'.esc_url($theme_link).'" title="'. esc_attr( get_the_title( get_the_ID() ) ) .'">
                    						<h3 class="mtkb-portfolio-name">'. esc_html( get_the_title( get_the_ID() ) ) .'</h3>
                    					</a>';
                    					$html.='<h4 class="mtkb-portfolio-category">'.wp_kses($all_categories, 'categories').'</h4>';
                    					$html.='<div class="mtkb-portfolio-metas">';
				                            $html.='<a href="'.esc_url($theme_link).'" title="'.esc_attr( get_the_title( get_the_ID() ) ).'" class="mtkb-portfolio-button">'.esc_html__("View More", 'mtkb').' </a>';
	                        			$html.='</div>';
	                      			$html.='</div>';              
	                  		$html.='</article>';            
	                	$html.='  </div>';
          			}
          			wp_reset_postdata();
          		}
			$html .= '</div>';
		$html .= '</div>';
		return $html;
	}

	/**
	 * Most viewed/recent portfolio listings shortcode
	 */
	function mtkb_shortcode_most_portfolio($params, $content=NULL) {
		extract( 
	    	shortcode_atts( 
		        array(
		            'number'				=> '',
		            'type'					=> '',
		            'columns'				=> '',
		            'additional_class'		=> '',
		    	), $params 
		    ) 
		);
		$post_type = 'mtkb-portfolio';
		if($type == 'most_viewed') {
			$portfolio_atts = array(
				'post_per_page'	 => $number,
				'post_type'  => $post_type,
				'meta_key'   => 'mtkb_post_views_count',
			    'orderby'    => 'meta_value_num',
			    'order'      => 'DESC',
			);

		} elseif($type == 'most_recent') {
			$portfolio_atts = array(
				'post_per_page'	=> $number,
				'post_type' => $post_type,
	            'orderby' 	=> 'date',
	            'order'   	=> 'DESC',
			);
		}

		$portfolio_query = new WP_Query($portfolio_atts);
		$html = '';
	    $html .= '<div class="mtkb-portfolio-container '.esc_html($additional_class).'">';
	      	$html .= '<div class="row">';
          		if($portfolio_query->have_posts()){
          			while ($portfolio_query->have_posts()) {
          				$portfolio_query->the_post();
          				$theme_link 				= get_permalink(get_the_ID());
	              		$thumbnail_src 				= wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'mtkb-portfolio-thumpnail' );
              			$all_categories 			= get_the_term_list( get_the_ID(), 'mtkb-portfolio-category', '', ' / ' );


              			$sticky_class = '';

              			if ( is_sticky(get_the_ID()) ) {
                  			$sticky_class = 'is-sticky';
              			}
                                                               
              			$html.='<div class="'.esc_attr($sticky_class).' '.esc_attr( get_the_title() ).' '.esc_attr($columns).' mtkb-portfolio-col">';
              				$html.='<article class="mtkb-portfolio-single">';
                				$html.='<div class="mtkb-portfolio-singleitem mtkb-box">';
                  					$html.='<a href="'.esc_url($theme_link).'" title="'. esc_attr( get_the_title( get_the_ID() ) ) .'"><img class="mtkb-portfolio-image" src="'.esc_url($thumbnail_src[0]).'" alt="'.esc_attr( get_the_title( get_the_ID() ) ).'"></a>';
                  					$html.='<div class="mtkb-portfolio-details">';
                    					$html.='<a href="'.esc_url($theme_link).'" title="'. esc_attr( get_the_title( get_the_ID() ) ) .'">
                    						<h3 class="mtkb-portfolio-name">'. esc_html( get_the_title( get_the_ID() ) ) .'</h3>
                    					</a>';
                    					$html.='<h4 class="mtkb-portfolio-category">'.wp_kses($all_categories, 'categories').'</h4>';
                    					$html.='<div class="mtkb-portfolio-metas">';
				                            $html.='<a href="'.esc_url($theme_link).'" title="'.esc_attr( get_the_title( get_the_ID() ) ).'" class="mtkb-portfolio-button">'.esc_html__("View More", 'mtkb').' </a>';
	                        			$html.='</div>';
	                      			$html.='</div>';              
	                  		$html.='</article>';            
	                	$html.='  </div>';
          			}
          			wp_reset_postdata();
          		}
			$html .= '</div>';
		$html .= '</div>';
		return $html;
	}

	//portfolio social share buttons 
	function mtkb_portfolios_share_buttons() {
		$html ='';
		$html .='<ul class="mtkb-portfolio-share">';
		$html .='<li><a class="social-share-btn fb" href="https://www.facebook.com/sharer/sharer.php?u='.get_the_permalink(get_the_ID()).'" title="'.esc_attr__('Share on Facebook', 'mtkb').'" target="_blank"><i class="fontello-icon-facebook"></i></a></li>';

		$html .='<li><a class="w-inline-block social-share-btn tw" href="https://twitter.com/intent/tweet?text='.get_the_title(get_the_ID()).':%20'.get_the_permalink(get_the_ID()).'" target="_blank" title="'.esc_attr__('Tweet', 'mtkb').'" ><i class="fontello-icon-twitter"></i></a></li>';

		$html .='<li><a class="w-inline-block social-share-btn pin" href="http://pinterest.com/pin/create/button/?url='.get_the_permalink(get_the_ID()).'&description='.get_the_title(get_the_ID()).'" target="_blank" title="'.esc_attr__('Pin it', 'mtkb').'"><i class="fontello-icon-pinterest"></i></a></li>';

		$html .='<li><a class="w-inline-block social-share-btn tmb" href="http://www.tumblr.com/share?v=3&u='.get_the_permalink(get_the_ID()).'&t='.get_the_title(get_the_ID()).'&s=" target="_blank" title="'.esc_attr__('Post to Tumblr', 'mtkb').'"><i class="fontello-icon-tumblr"></i></a></li>';

		$html .='<li><a class="w-inline-block social-share-btn email" href="mailto:?subject='.get_the_title(get_the_ID()).'&body=:'.get_the_permalink(get_the_ID()).'" target="_blank" title="'.esc_attr__('Email', 'mtkb').'"><i class="fontello-icon-mail-alt"></i></a></li>';

		$html .='<li><a class="w-inline-block social-share-btn lnk" href="http://www.linkedin.com/shareArticle?mini=true&url='.get_the_permalink(get_the_ID()).'&title='.get_the_title(get_the_ID()).'&summary=&source=" target="_blank" title="'.esc_attr__('Share on LinkedIn', 'mtkb').'"><i class="fontello-icon-linkedin"></i></a></li>';

		$html .='<li><a class="w-inline-block social-share-btn redd" href="http://www.reddit.com/submit?url='.get_the_permalink(get_the_ID()).'&title='.get_the_title(get_the_ID()).'" target="_blank" title="'.esc_attr__('Submit to Reddit', 'mtkb').'"><i class="fontello-icon-reddit-alien"></i></a></li>';
		$html .='</ul>';

		echo $html;
	}

}


