<?php

/**
 * The wp-bakery plugin mapping functionality of the plugin.
 *
 * @link       https://mtkb.com/
 * @since      1.0.0
 *
 * @package    Mtkb
 * @subpackage Mtkb/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Mtkb
 * @subpackage Mtkb/public
 * @author     mtkb <support@mtkb.com>
 */
class Mtkb_Wp_Bakery_Map {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Map Knowledgebase Shortcodes to WP Bakery
	 */
	
	function mtkb_vc_shortcodes(){
		if ( function_exists('vc_map') ) {
			// Mt Knowledgebase Search Bar
	        vc_map( 
	          	array(
		           "name" => esc_html__("MT knowledgebase Search Bar", "mtkb"),
		           "base" => "mt_knowledgebase_search",
		           "category" => esc_html__("Mt Knowledgebase", "mtkb"),
		           "params" => array(
		               	array(
		                  	"type" => "textfield",
		                  	"holder" => "div",
		                  	"class" => "",
		                  	"heading" => esc_html__( "Additional class","mtkb"),
		                  	"param_name" => "additional_class",
		                  	"value" => "",
		                  	"description" => esc_html__( "The additional class for further styling (optional).", "mtkb" )
		               	),
		               	array(
		                  	"type" => "textfield",
		                  	"holder" => "div",
		                  	"class" => "",
		                  	"heading" => esc_html__( "Search placeholder","mtkb"),
		                  	"param_name" => "placeholder",
		                  	"value" => "",
		                  	"description" => esc_html__( "The placeholder for the search bar.", "mtkb" )
		               	),
	           		),
	        	),
	        );

	        //Knowledge Grid Container
		  	vc_map( 
		    	array(
		        	"name" => esc_html__("Mt knowledgebase Grid Container", "mtkb"),
		        	"base" => "mt_knowledgebase_grid_container",
		        	"as_parent" => array(
		        		"only" => "mtkb_most,mtkb_list",
		        	), // Use only|except attributes to limit child shortcodes (separate multiple values with comma)
		        	"show_settings_on_create" => false,
		        	"category" => esc_html__("Mt Knowledgebase", "mtkb"),
		        	"is_container" => true,
		        	"params" => array(
		        	    array(
		        	        "type" => "textfield",
		        	        "heading" => esc_html__("Extra class name", "mtkb"),
		        	        "param_name" => "additional_class",
		        	        "description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
		        	    ),
		        	),
		        	"js_view" => 'VcColumnView'
		    	)
			);

		  	// categories array
			$mtkb_categories = get_terms('mtkb-knowledgebase-category');
	        $knowledgebase_categories = array();
	        if ($mtkb_categories) {
	          	foreach ( $mtkb_categories as $term ) {
	            	$knowledgebase_categories[$term->name] = $term->term_id;
	          	}
	        }

	        //	Knowledgebase List
		  	vc_map( 
				array(
	  				"name" => esc_html__("Mt Knowledgebase list", "mtkb"),
	  				"base" => "mt_knowledgebase_list",
	  				"as_child" => array(
		        		"only" => array("mtkb_grid_container" ),
		        	), // Use only|except attributes to limit parent (separate multiple values with comma)
	  				"params" => array(
	      			// add params same as with any other content element
	      				array(
	          				"type"         => "textfield",
	          				"holder"       => "div",
	          				"param_name"   => "number",
	          				"valuer"	   => "5",
	          				"heading"      => esc_html__("Number", "mtkb"),
	          				"description"  => esc_html__("Enter the number of the Knowledgebase items you want to be displayed.", "mtkb"),
	      				),

	      				array(
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Select Knowledgebase Category", "mtkb"),
	             			"param_name" => "category_id",
	             			"description" => esc_html__("Please select knowledgebase category", "mtkb"),
	             			"std" => 'Default value',
	             			"value" => $knowledgebase_categories,
	          			),
	      				array(
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Columns", "mtkb"),
	             			"param_name" => "columns",
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
							    esc_html__( '3 columns',  "mtkb"  ) => 'col-md-4',
							    esc_html__( '2 columns',  "mtkb"  ) => 'col-md-6',
							),
	          			),
	      				array(
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("List Style", "mtkb"),
	             			"param_name" => "version",
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
	             				esc_html__( 'Style 1',  "mtkb"  ) => '1',
							    esc_html__( 'Style 2',  "mtkb"  ) => '2',
	             			)
	          			),
	      				array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Extra class name", "mtkb"),
	            			"param_name" => "additional_class",
	            			"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
	        			),
	  				)
				) 
			);

			//	Knowledgebase Most Liked/ Viewed/ Recent
		  	vc_map( 
				array(
	  				"name" => esc_html__("Mt Knowledgebase most liked/viewed/recent", "mtkb"),
	  				"base" => "mt_knowledgebase_most",
	  				"as_child" => array(
		        		"only" => array("mtkb_grid_container" ),
		        	), // Use only|except attributes to limit parent (separate multiple values with comma)
	  				"params" => array(
	      			// add params same as with any other content element
	      				array(
	          				"type"         => "textfield",
	          				"holder"       => "div",
	          				"class"        => "",
	          				"param_name"   => "number",
	          				"heading"      => esc_html__("Number", "mtkb"),
	          				"description"  => esc_html__("Enter the number of the Knowledgebase items you want to be displayed.", "mtkb"),
	      				),
	      				array(
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Columns", "mtkb"),
	             			"param_name" => "columns",
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
							    esc_html__( '3 columns',  "mtkb"  ) => 'col-md-4',
							    esc_html__( '2 columns',  "mtkb"  ) => 'col-md-6',
							),
	          			),
	      				array(
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("List Type", "mtkb"),
	             			"param_name" => "type",
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
	             			 	esc_html__( 'Most Liked',  "mtkb"  ) => 'most_liked',
							    esc_html__( 'Most Viewed',  "mtkb"  ) => 'most_viewed',
							    esc_html__( 'Most Recent',  "mtkb"  ) => 'most_recent',
	             			)
	             		),
	      				array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Extra class name", "mtkb"),
	            			"param_name" => "additional_class",
	            			"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
	        			),
	        			array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Button text", "mtkb"),
	            			"param_name" => "button_text",
	                  		"value" => esc_html__( "Button Text","mtkb"),
	                  		"description" => esc_html__( "The text for the button.","mtkb"),
	        			),
	        			array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Button URL", "mtkb"),
	            			"param_name" => "button_url",
	            			"value" => esc_html__( "#","mtkb"),
	                  		"description" => esc_html__( "The link for the button.","mtkb"),
	        			),
	  				)
				) 
			);

		  	//	Knowledgebase Archive List A to Z
		  	vc_map( 
	          	array(
	           		"name" => esc_html__("Mt Knowledgebase List A to Z", "mtkb"),
	           		"base" => "mt_knowledgebase_list_a_z",
	           		"category" => esc_html__("Mt Knowledgebase", "mtkb"),
	           		"params" => array(
	               		array(
	                  		"type" => "textfield",
	                  		"holder" => "div",
	                  		"class" => "",
	                  		"heading" => esc_html__( "Additional class","mtkb"),
	                  		"param_name" => "additional_class",
	                  		"value" => "",
	                  		"description" => esc_html__( "The additional class for further styling (optional).","mtkb"),
	               		),
		           	)
		        )
	        );

	        //Knowledgebase Accordion nav
		  	vc_map( 
				array(
	  				"name" => esc_html__("Mt Knowledgebase Categories Accordion", "mtkb"),
	  				"base" => "mt_knowledgebase_categories_accordion",
	           		"category" => esc_html__("Mt Knowledgebase", "mtkb"),
	  				"params" => array(
	      			// add params same as with any other content element
	      				array(
	          				"type"         => "textfield",
	          				"holder"       => "div",
	          				"class"        => "",
	          				"param_name"   => "heading_title",
	          				"heading"      => esc_html__("Heading Title", "mtkb"),
	          				"description"  => esc_html__("Enter the title of the Knowledgebase categories accordion that you want to be displayed.", "mtkb"),
	      				), 
	      				array(
	          				"type"         => "dropdown",
	          				"holder"       => "div",
	          				"class"        => "",
	          				"param_name"   => "is_active",
	          				"heading"      => esc_html__("Select the Active Category", "mtkb"),
	          				"description"  => esc_html__("Select the Knowledgebase category that you want to be displayed open by deffault. ", "mtkb"),
	          				"std" => 'Default value',
	             			"value" => $knowledgebase_categories,
	      				),
	      				array(
	          				"type"         => "textfield",
	          				"holder"       => "div",
	          				"class"        => "",
	          				"param_name"   => "number",
	          				"heading"      => esc_html__("Number", "mtkb"),
	          				"description"  => esc_html__("Enter the number of the Knowledgebase items you want to be displayed in each category.", "mtkb"),
	      				),            				        				
	      				array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Extra class name", "mtkb"),
	            			"param_name" => "additional_class",
	            			"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
	        			),
	  				)
				) 
			);

	        //Knowledge Categories 
	        vc_map( 
				array(
	  				"name" => esc_html__("Mt Knowledgebase Categories Grid", "mtkb"),
	  				"base" => "mt_knowledgebase_category_grid",
	           		"category" => esc_html__("Mt Knowledgebase", "mtkb"),
	  				"params" => array(
	      			// add params same as with any other content element
	      				array(
	          				"type"         => "textfield",
	          				"holder"       => "div",
	          				"class"        => "",
	          				"param_name"   => "number",
	          				"heading"      => esc_html__("Number", "mtkb"),
	          				"description"  => esc_html__("Enter the number of the Knowledgebase items you want to be displayed in each category.", "mtkb"),
	      				),
	      				array(
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("List Style", "mtkb"),
	             			"param_name" => "style",
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
	             				esc_html__( 'Style 1',  "mtkb"  ) => '1',
							    esc_html__( 'Style 2',  "mtkb"  ) => '2',
	             			)
	          			),
	      				array(
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Columns", "mtkb"),
	             			"param_name" => "columns",
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
							    esc_html__( '3 columns',  "mtkb"  ) => 'col-md-4',
							    esc_html__( '2 columns',  "mtkb"  ) => 'col-md-6',
							),
	          			),  
	          			array(
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Show categories without knowledgebase article?", "mtkb"),
	             			"param_name" => "hide_empty",
	             			"std" => 'true',
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
	             			 	esc_html__( 'Yes',  "mtkb"  )     => 'true',
	             			 	esc_html__( 'No' ,  "mtkb"  )     => 'false',
	             			),
	          			),          				        				
	      				array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Extra class name", "mtkb"),
	            			"param_name" => "additional_class",
	            			"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
	        			),
	  				)
				) 
			);

			//Knowledge Category Accordion
	        vc_map( 
				array(
	  				"name" => esc_html__("Mt Knowledgebase Category Accordion", "mtkb"),
	  				"base" => "mt_knowledgebase_category_accordion",
	           		"category" => esc_html__("Mt Knowledgebase", "mtkb"),
	  				"params" => array(
	      			// add params same as with any other content element
	  					array(
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Select Knowledgebase Category", "mtkb"),
	             			"param_name" => "category_id",
	             			"description" => esc_html__("Please select knowledgebase category", "mtkb"),
	             			"std" => 'Default value',
	             			"value" => $knowledgebase_categories,
	          			),
	      				array(
	          				"type"         => "textfield",
	          				"holder"       => "div",
	          				"class"        => "",
	          				"param_name"   => "number",
	          				"heading"      => esc_html__("Number", "mtkb"),
	          				"description"  => esc_html__("Enter the number of the Knowledgebase items you want to be displayed.", "mtkb"),
	      				),
	      				array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Extra class name", "mtkb"),
	            			"param_name" => "additional_class",
	            			"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
	        			),
	  				)
				) 
			);
		}
	}
	function mtkb_changelog_vc_shortcodes() {
		if ( function_exists('vc_map') ) {

			//Changelog List Container
		  	vc_map( 
		    	array(
		        	"name" => esc_html__("Mt Changelog List", "mtkb"),
		        	"base" => "mt_changelog_container",
		        	"as_parent" => array("only" => "mt_changelog_item",), // Use only|except attributes to limit child shortcodes (separate multiple values with comma)
		        	"show_settings_on_create" => true,
		        	// "icon" => plugins_url( 'images/map_pins.svg', __FILE__ ),
		        	"category" => esc_html__("Mt Knowledgebase", "mtkb"),
		        	"is_container" => true,
		        	"params" => array(
		        		array(
	          				"type"         => "textfield",
	          				"holder"       => "div",
	          				"class"        => "",
	          				"param_name"   => "title",
	          				"heading"      => esc_html__("Title", "mtkb"),
	          				"description"  => esc_html__("Enter the title of the Changelog list that you wish to be displayed.", "mtkb"),
	      				), 
		        	    array(
		        	        "type" => "textfield",
		        	        "heading" => esc_html__("Extra class name", "mtkb"),
		        	        "param_name" => "additional_class",
		        	        "description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
		        	    ),
		        	),
		        	"js_view" => 'VcColumnView'
		    	)
			);

				//KChangelog List Item
		  	vc_map( 
				array(
	  				"name" => esc_html__("Mt Changelog List Item", "mtkb"),
	  				"base" => "mt_changelog_item",
	           		"category" => esc_html__("Mt Knowledgebase", "mtkb"),
	  				"as_child" => array("only" => "mt_changelog_container"), // Use only|except attributes to limit parent (separate multiple values with comma)
	  				"params" => array(
	      			// add params same as with any other content element
	  					array(
							'type' => 'textarea_html',
							'holder' => 'div',
							'heading' => esc_html__( 'Text', 'mtkb' ),
							'param_name' => 'content',
							'value' => '<p>' . esc_html__( 'I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'js_composer' ) . '</p>',
						),
	      				array(
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Type", "mtkb"),
	             			"param_name" => "item_type",
	             			"value" => array(
	             			 	esc_html__( 'Select Option',"mtkb" ) 	=> '',
	             			 	esc_html__( 'New',"mtkb" )     		=> 'new',
	             			 	esc_html__( 'Update',"mtkb" )     	=> 'update',
	             			 	esc_html__( 'Improvement',"mtkb" )  	=> 'improvement',
	             			 	esc_html__( 'Fix',"mtkb" ) 			=> 'fix',
	             			)
	          			),    				        				
	      				array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Extra class name", "mtkb"),
	            			"param_name" => "additional_class",
	            			"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
	        			),
	  				)
				) 
			);

		  	//Single Changelog
		  	$changelog_args = array(
		  		'post_type'		=> 'mtkb-changelog',
		  		'post_status'	=> 'publish',
		  	);
		  	$changelogs_array = array();
		  	$changelog_query = new Wp_Query($changelog_args);
		  	if( $changelog_query->have_posts() ){
		  		while ( $changelog_query->have_posts() ) {
		  			$changelog_query->the_post();
		  			$changelogs_array[get_the_title()] = get_the_ID();
		  		}
		  	}
		  	vc_map( 
				array(
	  				"name" => esc_html__("Mt Single Changelog", "mtkb"),
	  				"base" => "mt_single_changelog",
	           		"category" => esc_html__("Mt Knowledgebase", "mtkb"),
	  				"params" => array(
	      			// add params same as with any other content element
	      				array(
	          				"type"         => "dropdown",
	          				"holder"       => "div",
	          				"class"        => "",
	          				"param_name"   => "changelog_id",
	          				"heading"      => esc_html__("Changelog", "mtkb"),
	          				"description"  => esc_html__("Select the Changelog that you want to be displayed.", "mtkb"),
	             			"value" => $changelogs_array,
	      				), 
	      				array(
		                  	"type" => "textfield",
		                  	"holder" => "div",
		                  	"class" => "",
		                  	"heading" => esc_html__( "Changelog Version","mtkb"),
		                  	"param_name" => "changelog_version",
		                  	"value" => "",
		                  	"description" => esc_html__( "Type in the Changelog Version that You want to desiplay.", "mtkb" )
		               	),
	      				array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Extra class name", "mtkb"),
	            			"param_name" => "additional_class",
	            			"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
	        			),
	  				)
				) 
			);
		}
	}

	function mtkb_faqs_vc_shortcodes() {
		if ( function_exists('vc_map') ) {
			//FAQs container
		  	vc_map( 
		    	array(
		        	"name" => esc_html__("Mt FAQs Container", "mtkb"),
		        	"base" => "mt_faqs_container",
		        	"as_parent" => array('only' => 'mt_faqs_item',), // Use only|except attributes to limit child shortcodes (separate multiple values with comma)
		        	"show_settings_on_create" => true,
		        	// "icon" => plugins_url( 'images/map_pins.svg', __FILE__ ),
		        	"category" => esc_html__("Mt Knowledgebase", "mtkb"),
		        	"is_container" => true,
		        	"params" => array(
		        	    array(
		        	        "type" => "textfield",
		        	        "heading" => esc_html__("Extra class name", "mtkb"),
		        	        "param_name" => "additional_class",
		        	        "description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
		        	    ),
		        	),
		        	"js_view" => 'VcColumnView'
		    	)
			);

			//FAQs items
		  	vc_map( 
				array(
	  				"name" => esc_html__("Mt FAQs Item", "mtkb"),
	  				"base" => "mt_faqs_item",
	           		"category" => esc_html__("Mt Knowledgebase", "mtkb"),
	  				"as_child" => array('only' => 'mt_faqs_container'), // Use only|except attributes to limit parent (separate multiple values with comma)
	  				"params" => array(
	      			// add params same as with any other content element
	      				array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Title", "mtkb"),
	            			"param_name" => "title",
	            			"description"  => esc_html__("Enter the title of the FAQ that you wish to be displayed.", "mtkb"),
	        			),   	
	        			array(
	            			"type" => "textarea_html",
	            			"heading" => esc_html__("Content", "mtkb"),
	            			"param_name" => "content",
	            			"description"  => esc_html__("Enter the title of the FAQ that you wish to be displayed.", "mtkb"),
	        			),  			        				
	      				array(
	            			"type" => "textfield",
	            			"heading" => esc_html__("Extra class name", "mtkb"),
	            			"param_name" => "additional_class",
	            			"description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.","mtkb"),
	        			),
	  				)
				) 
			);
		}
	}
	/**
	||-> Map Shortcode in Visual Composer with: vc_map();
	*/
	function mtkb_portfolio_vc_shortcodes() {
		if ( function_exists('vc_map') ) {
		  	$search_filter = array('Choose' => 'Null','Search Enable ' => 'search_on', 'Search Disable' => 'search_off');
		  	$tags_filter = array('Choose' => 'Null','Tags Enable ' => 'tags_on', 'Tags Disable' => 'tags_off');
		  	$category_filter = array('Choose' => 'Null','Category Enable ' => 'category_on', 'Category Disable' => 'category_off');
		  	// categories array
			$mtkb_portfolio_categories = get_terms('mtkb-portfolio-category');
	        $portfolio_categories = array();
	        if ($mtkb_portfolio_categories) {
	          	foreach ( $mtkb_portfolio_categories as $term ) {
	            	$portfolio_categories[$term->name] = $term->term_id;
	          	}
	        }
		  	vc_map( 
		  		array(
			     	"name" => esc_attr__("MT Portfolio Filters", 'mtkb'),
			     	"base" => "mt_portfolio_filters",
		           	"category" => esc_html__("Mt Knowledgebase", "mtkb"),
			     	"params" => array(
			        	array(
			        	  	"group" => "Options",
			        	  	"type" => "textfield",
			        	  	"holder" => "div",
			        	  	"class" => "",
			        	  	"heading" => esc_attr__( "Number of posts", 'mtkb' ),
			        	  	"param_name" => "number",
			        	  	"description" => esc_attr__( "Enter number of portfolio listings to show.", 'mtkb' )
			        	),
			        	array(
			        	  	"group" => "Options",
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Columns", "mtkb"),
	             			"param_name" => "columns",
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
							    esc_html__( '3 columns',  "mtkb"  ) => 'col-md-4',
							    esc_html__( '2 columns',  "mtkb"  ) => 'col-md-6',
							),
	          			),
	          			array(
			        	  	"group" => "Options",
		                  	"type" => "textfield",
		                  	"holder" => "div",
		                  	"class" => "",
		                  	"heading" => esc_html__( "Additional class","mtkb"),
		                  	"param_name" => "additional_class",
		                  	"value" => "",
		                  	"description" => esc_html__( "The additional class for further styling (optional).", "mtkb" )
		               	),
		               				       		array(
			          		"group" => "Options",
			          		"type" => "dropdown",
			          		"holder" => "div",
			          		"heading" => esc_attr__( "Enable or disable search filter", 'mtkb' ),
			          		"param_name" => "searchfilter",
			          		"value" => $search_filter,
			        	),
			        	array(
			          		"group" => "Options",
			          		"type" => "dropdown",
			          		"holder" => "div",
			          		"heading" => esc_attr__( "Enable or disable category filter", 'mtkb' ),
			          		"param_name" => "categoryfilter",
			          		"value" => $category_filter,
			        	),
			        	array(
			          		"group" => "Options",
			          		"type" => "dropdown",
			          		"holder" => "div",
			          		"heading" => esc_attr__( "Enable or disable tags filter", 'mtkb' ),
			          		"param_name" => "tagsfilter",
			          		"value" => $tags_filter,
			        	),
			      	)	
			  	)
		  	);
		  	vc_map( 
		  		array(
			     	"name" => esc_attr__("MT Portfolio Category", 'mtkb'),
			     	"base" => "mt_portfolio_category",
		           	"category" => esc_html__("Mt Knowledgebase", "mtkb"),
			     	"params" => array(
			        	array(
			        	  	"group" => "Options",
			        	  	"type" => "textfield",
			        	  	"holder" => "div",
			        	  	"class" => "",
			        	  	"heading" => esc_attr__( "Number of posts", 'mtkb' ),
			        	  	"param_name" => "number",
			        	  	"description" => esc_attr__( "Enter number of portfolio listings to show.", 'mtkb' )
			        	),
			        	array(
			        	  	"group" => "Options",
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Columns", "mtkb"),
	             			"param_name" => "columns",
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
							    esc_html__( '3 columns',  "mtkb"  ) => 'col-md-4',
							    esc_html__( '2 columns',  "mtkb"  ) => 'col-md-6',
							),
	          			),
	          			array(
			        	  	"group" => "Options",
		                  	"type" => "textfield",
		                  	"holder" => "div",
		                  	"class" => "",
		                  	"heading" => esc_html__( "Additional class","mtkb"),
		                  	"param_name" => "additional_class",
		                  	"value" => "",
		                  	"description" => esc_html__( "The additional class for further styling (optional).", "mtkb" )
		               	),
		               	array(
			        	  	"group" => "Options",
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Select Knowledgebase Category", "mtkb"),
	             			"param_name" => "category_id",
	             			"description" => esc_html__("Please select the portfolio category", "mtkb"),
	             			"std" => esc_html__('Default value', "mtkb"),
	             			"value" => $portfolio_categories,
	          			),
			      	)	
			  	)
		  	);
		  	vc_map( 
		  		array(
			     	"name" => esc_attr__("MT Portfolio Most Viewed/Recet", 'mtkb'),
			     	"base" => "mt_portfolio_most",
		           	"category" => esc_html__("Mt Knowledgebase", "mtkb"),
			     	"params" => array(
			        	array(
			        	  	"group" => "Options",
			        	  	"type" => "textfield",
			        	  	"holder" => "div",
			        	  	"class" => "",
			        	  	"heading" => esc_attr__( "Number of posts", 'mtkb' ),
			        	  	"param_name" => "number",
			        	  	"description" => esc_attr__( "Enter number of portfolio listings to show.", 'mtkb' )
			        	),
			        	array(
			        	  	"group" => "Options",
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Columns", "mtkb"),
	             			"param_name" => "columns",
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
							    esc_html__( '3 columns',  "mtkb"  ) => 'col-md-4',
							    esc_html__( '2 columns',  "mtkb"  ) => 'col-md-6',
							),
	          			),
	          			array(
			        	  	"group" => "Options",
		                  	"type" => "textfield",
		                  	"holder" => "div",
		                  	"class" => "",
		                  	"heading" => esc_html__( "Additional class","mtkb"),
		                  	"param_name" => "additional_class",
		                  	"value" => "",
		                  	"description" => esc_html__( "The additional class for further styling (optional).", "mtkb" )
		               	),
		               	array(
			        	  	"group" => "Options",
	             			"type" => "dropdown",
	             			"holder" => "div",
	             			"class" => "",
	             			"heading" => esc_html__("Type", "mtkb"),
	             			"param_name" => "type",
	             			"value" => array(
							    esc_html__( 'Select Option',  "mtkb"  ) => '',
							    esc_html__( 'Most Viewed',  "mtkb"  ) => 'most_viewed',
							    esc_html__( 'Most Recent',  "mtkb"  ) => 'most_recent',
	             			)
	             		),
			      	)	
			  	)
		  	);
		}
	}


}

function mtkb_widgets_cotainers() {
	//Your "container" content element should extend WPBakeryShortCodesContainer class to inherit all required functionality
  	if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
      	class WPBakeryShortCode_mt_knowledgebase_grid_container extends WPBakeryShortCodesContainer {
    	}
      	class WPBakeryShortCode_mt_knowledgebase_list extends WPBakeryShortCode {
      	}
      	class WPBakeryShortCode_mt_knowledgebase_most extends WPBakeryShortCode {
      	}
  	}
}
function mtkb_changelogs_widgets_cotainers() {
	//Your "container" content element should extend WPBakeryShortCodesContainer class to inherit all required functionality
  	if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
      	class WPBakeryShortCode_mt_changelog_container extends WPBakeryShortCodesContainer {
    	}
      	class WPBakeryShortCode_mt_changelog_item extends WPBakeryShortCode {
      	}
  	}
}
function mtkb_faqs_widgets_cotainers() {
	//Your "container" content element should extend WPBakeryShortCodesContainer class to inherit all required functionality
  	if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
      	class WPBakeryShortCode_mt_faqs_container extends WPBakeryShortCodesContainer {
    	}
      	class WPBakeryShortCode_mt_faqs_item extends WPBakeryShortCode {
      	}
  	}
}

add_action('init', 'mtkb_widgets_cotainers'); 
add_action('init', 'mtkb_changelogs_widgets_cotainers'); 
add_action('init', 'mtkb_faqs_widgets_cotainers'); 