<?php 

/**
||-> Shortcode: Changelog Items List
*/

namespace Elementor;

class Mtkb_Changelog_List_Widget extends Widget_Base {
    public function get_name() {
        return 'changelog_list';
    }

    public function get_title() {
        return esc_html__('MTKB - Changelog List', 'mtkb');
    }

    public function get_icon() {
        return 'fab fa-elementor';
    }

    public function get_categories() {
        return [ 'mtkb-widgets' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_title',
            [
                'label' =>  esc_html__( 'Content', 'mtkb' ),
            ]
        );

        $this->add_control(
            'title',
            [
                'label' =>  esc_html__( 'Heading title', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => '',
                'description' =>  esc_html__( 'The title of the list.', 'mtkb' ),
            ]
        );

        $this->add_control(
            'additional_class',
            [
                'label' =>  esc_html__( 'Additional Class', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => '',
                'description' =>  esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'mtkb' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'item_type',
            [
                'label' =>  esc_html__( 'List item type', 'mtkb' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'new',
                'options' => [
                    'new' =>  esc_html__( 'New', 'mtkb' ),
                    'update' =>  esc_html__( 'Update', 'mtkb' ),
                    'improvement' =>  esc_html__( 'Improvement', 'mtkb' ),
                    'fix' =>  esc_html__( 'Fix', 'mtkb' ),
                ]
            ]
        );

        $repeater->add_control(
            'additional_class',
            [
                'label' =>  esc_html__( 'Additional Class', 'mtkb' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '',
                'description' =>  esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'mtkb' ),
            ]
        );

        $repeater->add_control(
            'content',
            [
                'label' =>  esc_html__( 'List content', 'mtkb' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => '',
                'description' =>  esc_html__( 'The Content of the list item.', 'mtkb' ),
            ]
        );


        $this->add_control(
            'changelog_items',
            [
                'label' =>  esc_html__( 'Changelog Items', 'mtkb' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings           = $this->get_settings_for_display();
        $additional_class   = $settings['additional_class'];
        $title              = $settings['title'];
        $changelog_items    = $settings['changelog_items'];

        $html ='';
        $html .= '<div class="mtkb-knowledgebase-changelog-container '.esc_attr($additional_class).'">';
            $html .= '<h3 class="changelog-title">'.esc_html($title).'</h3>';
            $html .= '<ul class="mtkb-knowledgebase-changelog-list">';

                foreach ($changelog_items as $changelog_item) {
                    $item_additional_class  = $changelog_item['additional_class'];
                    $type                   = $changelog_item['item_type'];
                    $content                = $changelog_item['content'];
                    $icon                   = '<i class="fontello-icon-plus"></i>';

                    if($type == "new") {
                        $icon = '<i class="fontello-icon-plus"></i>';
                    } elseif($type == "update") {
                        $icon = '<i class="fontello-icon-arrows-cw"></i>';
                    } elseif($type == "improvement") {
                        $icon = '<i class="fontello-icon-ok"></i>';
                    } elseif($type == "fix") {
                        $icon = '<i class="fontello-icon-link"></i>';
                    }

                    $html .= '<li class="mtkb_changelog_list_item '.esc_attr($type).' '.esc_attr($item_additional_class).'">';
                        $html .= wp_kses($icon, 'icon') . esc_html($content);
                    $html .= '</li>';
                }
            $html .= '</ul>';
        $html .= '</div>';

        echo $html;
    }
    protected function _content_template() {

    }
}