<?php 

/**
||-> Shortcode: FAQs Accordion
*/

namespace Elementor;

class Mtkb_Faqs_Accordion_Widget extends Widget_Base {
    public function get_name() {
        return 'faqs_accordion';
    }

    public function get_title() {
        return esc_html__('MTKB - FAQs Accordion', 'mtkb');
    }

    public function get_icon() {
        return 'fab fa-elementor';
    }

    public function get_categories() {
        return [ 'mtkb-widgets' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_title',
            [
                'label' => esc_html__( 'Content', 'mtkb' ),
            ]
        );

        $this->add_control(
            'additional_class',
            [
                'label' => esc_html__( 'Additional Class', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => '',
                'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'mtkb' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => '',
                'description' => esc_html__( 'The FAQ title', 'mtkb' ),
            ]
        );

        $repeater->add_control(
            'content',
            [
                'label' => esc_html__( 'Content', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => '',
                'description' => esc_html__( 'The FAQ content', 'mtkb' ),
            ]
        );

        $repeater->add_control(
            'additional_class',
            [
                'label' => esc_html__( 'Additional Class', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => '',
                'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'mtkb' ),
            ]
        );

        $this->add_control(
            'faqs',
            [
                'label' => esc_html__( 'Frequently Asked Question', 'plugin-domain' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        global $esio_redux;
        $settings           = $this->get_settings_for_display();
        $additional_class   = $settings['additional_class'];
        $faqs               = $settings['faqs'];

        $html = '';
        $html .='<div class="mtkb-knowledgebase-faqs-container '.esc_attr($additional_class).'">';
            $html .= '<ul class="mtkb-knowledgebase-faqs">';

            foreach (  $faqs as $faq ) {
                $title              = $faq['title'];
                $additional_class   = $faq['additional_class'];
                $content            = $faq['content'];

                $html .= '<li class="mtkb-knowledgebase-faqs-item '.esc_attr($additional_class).'"> 
                    <div class="faq-title-holder">
                        <h3 class="faq-title">'.esc_html( $title ).'<i class="fontello-icon-right-open"></i></h3>
                    </div>
                    <div class="faq-content-holder">
                        <p>'.esc_html( $content ).'</p>
                    </div>
                </li>';
            }
            $html .= '</ul>';
        $html .= '</div>';

        echo $html;
    }
    protected function _content_template() {

    }
}