<?php 

/**
||-> Shortcode: Mt Knowlegebase archive shortcode
*/

namespace Elementor;

class Mtkb_Knowledgebase_Categories_Grid_Widget extends Widget_Base {
    public function get_name() {
        return 'knowledge_categories_grid';
    }

    public function get_title() {
        return esc_html__('MTKB - Knowledgebase Categories Grid', 'mtkb');
    }

    public function get_icon() {
        return 'fab fa-elementor';
    }

    public function get_categories() {
        return [ 'mtkb-widgets' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_title',
            [
                'label' => esc_html__( 'Content', 'mtkb' ),
            ]
        );

        $this->add_control(
            'additional_class',
            [
                'label' => esc_html__( 'Additional Class', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => '',
                'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'mtkb' ),
            ]
        );

        $this->add_control(
            'style',
            [
                'label' => esc_html__( 'Knowledgebase List version', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::SELECT,
                'default' => '2',
                'description' => esc_html__( 'Choose the Knowledgebase List version', 'mtkb' ),
                'options' => [
                    '1' => esc_html__( 'Version 1', 'mtkb' ),
                    '2' => esc_html__( 'Version 2', 'mtkb' ),
                ]
            ]
        );

        $this->add_control(
            'columns',
            [
                'label' => esc_html__( 'columns', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::SELECT,
                'default' => 'col-md-4',
                'description' => esc_html__( 'Choose the width for the Category boxes', 'mtkb' ),
                'options' => [
                    'col-md-4'  => esc_html__( '3 columns', 'mtkb' ),
                    'col-md-6'  => esc_html__( '2 columns', 'mtkb' ),
                ]
            ]
        );

        $this->add_control(
            'number',
            [
                'label' => esc_html__( 'Knowledgebase Posts Number', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::NUMBER,
                'default' => '5',
                'description' => esc_html__( 'The number of Knowledgebase posts to be displayed for each category', 'mtkb' ),
            ]
        );

        $this->add_control(
            'hide_empty',
            [
                'label' => esc_html__( 'Hide empty categories', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::SWITCHER,
                'default' => 'true',
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        global $esio_redux;
        $settings = $this->get_settings_for_display();
        $additional_class   = $settings['additional_class'];
        $hide_empty         = $settings['hide_empty'];
        $style              = $settings['style'];
        $number             = $settings['number'];
        $hide_empty         = $settings['hide_empty'];
        $columns             = $settings['columns'];

        if(!$hide_empty || $hide_empty == '') {
            $hide_empty = true;
        } elseif ($hide_empty == 'yes')
            $hide_empty = false;

        $kb_categories = get_terms(array(
            'taxonomy' => 'mtkb-knowledgebase-category',
            'hide_empty' => $hide_empty,
        ));

        $html = '';
        $html .= '<div class="row mtkb-knowledgebase-categories-grid '.esc_attr($additional_class).'">';

            foreach ($kb_categories as $kb_category) {
                $category_id = $kb_category->term_id;
                $knowledgebase_args = array(
                    'posts_per_page'   => $number,
                    'post_type'        => 'mtkb-knowledgebase',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'mtkb-knowledgebase-category',
                            'field' => 'term_id',
                            'terms' => $category_id
                        )
                    ),
                    'post_status'      => 'publish' 
                );
                if(!$style || $style == '') {
                    $style = '2';
                }

                $knowledgebase_query = new \WP_Query($knowledgebase_args);
                $knowledgebase_count = $knowledgebase_query->found_posts;

                $html .='<div class="'.esc_attr($columns).'">
                    <div class="mtkb_knowledge-list'.esc_attr($style).'">
                        <div class="heading-submenu">
                            <h3 class="heading">
                                <a class="heading-link" href="'.esc_url( get_term_link($category_id) ).'">
                                    <i class="fontello-icon-dot-circled" aria-hidden="true"></i>'.esc_html($kb_category->name).'
                                </a>
                            </h3>
                            <ul class="submenu">';
                                if($knowledgebase_query->have_posts()) {
                                    while ($knowledgebase_query->have_posts()) {
                                        $knowledgebase_query->the_post(); 
                                        $html .= '<li class="post_title">
                                            <a href="'.esc_url( get_permalink() ).'">'.esc_html( get_the_title() ).'</a>
                                        </li>';
                                    }
                                    wp_reset_postdata();
                                }
                            $html .= '</ul>
                        </div>';
                        if($style == '2') {
                            $html .='<a class="count-link" href="'.esc_url( get_term_link($category_id) ).'">'.sprintf( esc_html(_n( '%s Article in this category', '%s Articles in this category', $knowledgebase_count, 'mtkb' )), number_format_i18n( $knowledgebase_count ) ).'</a>';
                        } elseif($style == '1') {
                            $html .= '<a class="count-link" href="'.esc_url( get_term_link($category_id) ).'">' .esc_html__('View all', 'mtkb').' <i class="fontello-icon-right" aria-hidden="true"></i></a>';                           
                        }

                    $html .='</div>
                </div>';
            }

        $html .= '</div>';

        echo $html;
    }
    protected function _content_template() {

    }
}