<?php 

/**
||-> Shortcode: Mt Knowlegebase category grid
*/

namespace Elementor;

class Mtkb_Knowledgebase_Category_Widget extends Widget_Base {
    public function get_name() {
        return 'knowledgebase_category';
    }

    public function get_title() {
        return esc_html__('MTKB - Knowledgebase Category', 'mtkb');
    }

    public function get_icon() {
        return 'fab fa-elementor';
    }

    public function get_categories() {
        return [ 'mtkb-widgets' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_title',
            [
                'label' => esc_html__( 'Content', 'mtkb' ),
            ]
        );

        $this->add_control(
            'additional_class',
            [
                'label' => esc_html__( 'Additional Class', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => '',
                'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'mtkb' ),
            ]
        );

        $this->add_control(
            'version',
            [
                'label' => esc_html__( 'Knowledgebase List version', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::SELECT,
                'default' => '2',
                'description' => esc_html__( 'Choose the Knowledgebase List version', 'mtkb' ),
                'options' => [
                    '1' => esc_html__( 'Version 1', 'mtkb' ),
                    '2' => esc_html__( 'Version 2', 'mtkb' ),
                ]
            ]
        );

        $knowledgebase_category_tax = get_terms('mtkb-knowledgebase-category');
        $knowledgebase_category = array();
        if ($knowledgebase_category_tax) {
            foreach ( $knowledgebase_category_tax as $term ) {
                $knowledgebase_category[$term->term_id] = $term->name;
            }
        }

        $this->add_control(
            'category_id',
            [
                'label' => esc_html__( 'Category', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'description' => esc_html__( 'Select the category', 'mtkb' ),
                'options' => $knowledgebase_category,
            ]
        );

        $this->add_control(
            'number',
            [
                'label' => esc_html__( 'Knowledgebase Posts Number', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::NUMBER,
                'default' => '5',
                'description' => esc_html__( 'Type here the number of Knowledgebase posts to be displayed', 'mtkb' ),
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        global $esio_redux;
        $settings = $this->get_settings_for_display();
        $additional_class   = $settings['additional_class'];
        $category_id        = $settings['category_id'];
        $version            = $settings['version'];
        $number             = $settings['number'];

        $html = '';
        
        $args_knowledgebase = array(
            'posts_per_page'   => $number,
            'post_type'        => 'mtkb-knowledgebase',
            'tax_query' => array(
                array(
                    'taxonomy' => 'mtkb-knowledgebase-category',
                    'field' => 'term_id',
                    'terms' => $category_id
                )
            ),
            'post_status'      => 'publish' 
        );  

        $query_knowledgebase = new \WP_Query( $args_knowledgebase);
        $category_title = get_term( $category_id )->name;
        $category_slug = get_term( $category_id )->slug;
        $icon = '';
        if($version == '2') {
            $icon = '<i class="fontello-icon-dot-circled" aria-hidden="true"></i>';
        }

        $html .= '<div class="mtkb_knowledge-list'.esc_attr($version).' '.esc_attr($additional_class).'">';
            $html .= '<div class="heading-submenu">';
                $html .= '<h3 class="heading">';
                    if($version == '2') {
                        $html .= '<a class="heading-link" href="'.esc_url( get_term_link( get_term( $category_id ) ) ).'">';
                            $html .= $icon . esc_html($category_title) .'
                        </a>';
                    } elseif( $version == '1' ) {
                        $html .= $category_title;
                    }

                $html .= '</h3>';
                $html .= '<ul class="submenu">';
                    if($query_knowledgebase->have_posts()) {
                        while ($query_knowledgebase->have_posts()) {
                            $query_knowledgebase->the_post();
                            $html.='<li class="post_title">
                            <a href="'.esc_url( get_permalink( get_the_ID() ) ).'" title="'.esc_attr(get_the_title()).'">'.esc_html(get_the_title()).'</a>
                            </li>';      
                        }
                        wp_reset_postdata();
                    }
                $html .= '</ul>';
            $html .= '</div>';

            if($version == '2') {
                $knowledgebase_count = $query_knowledgebase->post_count;
                $html .='<a class="count-link" href="'.esc_url( get_term_link( get_term( $category_id ) ) ).'">'.sprintf( esc_html(_n( '%s Article in this category', '%s Articles in this category', $knowledgebase_count, 'mtkb' )), number_format_i18n( $knowledgebase_count ) ).'</a>';
            } elseif ($version == '1') {
                $html .= '<a class="count-link" href="'.esc_url( get_term_link( get_term( $category_id ) ) ).'">' .esc_html__('View all', 'mtkb').' <i class="fontello-icon-right" aria-hidden="true"></i></a>';
            }
        $html .= '</div>';


        echo $html;
    }
    protected function _content_template() {

    }
}