<?php 

/**
||-> Shortcode: Mt Knowlegebase most liked/viewed/recent
*/

namespace Elementor;

class Mtkb_Knowledgebase_Grid_Most_Widget extends Widget_Base {
    public function get_name() {
        return 'knowledge_most';
    }

    public function get_title() {
        return esc_html__('MTKB - Knowledgebase Most Liked/ Viewed/ Recent', 'mtkb');
    }

    public function get_icon() {
        return 'fab fa-elementor';
    }

    public function get_categories() {
        return [ 'mtkb-widgets' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_title',
            [
                'label' => esc_html__( 'Content', 'mtkb' ),
            ]
        );

        $this->add_control(
            'type',
            [
                'label' => esc_html__( 'Type', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::SELECT,
                'default' => '2',
                'description' => esc_html__( 'Choose the Knowledgebase List version', 'mtkb' ),
                'options' => [
                    'most_liked' => esc_html__( 'Knowledgebase List Most Liked', 'mtkb' ),
                    'most_viewed' => esc_html__( 'Knowledgebase List Most Viewed', 'mtkb' ),
                    'most_recent' => esc_html__( 'Knowledgebase List Recent', 'mtkb' ),
                ]
            ]
        );

        $this->add_control(
            'additional_class',
            [
                'label' => esc_html__( 'Additional Class', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => '',
                'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'mtkb' ),
            ]
        );

        $this->add_control(
            'number',
            [
                'label' => esc_html__( 'Knowledgebase Posts Number', 'mtkb' ),
                'label_block' => true,
                'type' => Controls_Manager::NUMBER,
                'default' => '5',
                'description' => esc_html__( 'Type here the number of Knowledgebase posts to be displayed', 'mtkb' ),
            ]
        );
        $this->add_control(
            'button_text',
            [
                'label' => esc_html__( 'Button Text', 'mtkb' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'View More',
                'description' => esc_html__( 'Type here the Text of the Button', 'mtkb' ),
            ]
        );

        $this->add_control(
            'button_url',
            [
                'label' => esc_html__( 'Button Url', 'mtkb' ),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'description' => esc_html__( 'Type here the URL of the Button', 'mtkb' ),
            ]
        );

    }

    protected function render() {
        $settings           = $this->get_settings_for_display();
        $additional_class   = $settings['additional_class'];
        $number             = $settings['number'];
        $type               = $settings['type'];
        $button_url               = $settings['button_url'];
        $button_text               = $settings['button_text'];

        $post_type = 'mtkb-knowledgebase';
        if($type == 'most_liked') {
            $Knowledgebase_atts = array(
                'posts_per_page'    => $number,
                'post_type'         => $post_type,
                'orderby'           => 'meta_value_num',
                'meta_key'          => 'mtkb_love_count',
                'order'             => 'DESC',
            );
        } elseif($type == 'most_viewed') {
            $Knowledgebase_atts = array(
                'posts_per_page'    => $number,
                'post_type'         => $post_type,
                'orderby'           => 'meta_value_num',
                'meta_key'          => 'mtkb_post_views_count',
                'order'             => 'DESC',
            );

        } elseif($type == 'most_recent') {
            $Knowledgebase_atts = array(
                'posts_per_page'    => $number,
                'post_type'         => $post_type,
                'orderby'           => 'date',
                'order'             => 'DESC',
            );
        }

        $Knowledgebase_list = new \WP_Query($Knowledgebase_atts);
        $html = '';
        if ($Knowledgebase_list->have_posts()) {
            $html .= '<div class="mtkb_knowledge-list-most mtkb_knowledge-list '.esc_attr($additional_class).'">';
                $html .= '<div class="heading-submenu">';
                    $html .= '<h3 class="heading">';
                        $count = $Knowledgebase_list->post_count;
                        $count_text = sprintf( esc_html(_n( '%s Article', '%s Articles', $count, 'mtkb' )), number_format_i18n( $count ) );
                        if($type == 'most_liked') {
                            $html .= '<i class="fontello-icon-star"></i>' . esc_html__('Most Liked', 'mtkb') .'<span class="mtkb-knowledgebase-count">'. esc_html($count_text).'</span>';
                        } elseif( $type == 'most_viewed' ) {
                            $html .= '<i class="fontello-icon-eye"></i>' . esc_html__('Most Viewed', 'mtkb') .'<span class="mtkb-knowledgebase-count">'. esc_html($count_text).'</span>';
                        } elseif( $type == 'most_recent' ) {
                            $html .= '<i class="fontello-icon-doc-inv"></i>' . esc_html__('Most Recent', 'mtkb') .'<span class="mtkb-knowledgebase-count">'. esc_html($count_text).'</span>';
                        }
                    $html .= '</h3>';
                    $html .= '<ul class="submenu">';
                        while ($Knowledgebase_list->have_posts()) {
                            $Knowledgebase_list->the_post();
                            $html.='<li class="post_title">
                                <a href="'.esc_url( get_permalink( get_the_ID() ) ).'">'.esc_html(get_the_title()).'</a>
                            </li>';      
                        }
                        wp_reset_postdata();
                    $html .= '</ul>';
                $html .= '</div>';
                $html .= '<a class="count-link" href="'.esc_url($button_url['url']).'">'.esc_html($button_text).' <i class="fontello-icon-right" aria-hidden="true"></i></a>';
            $html .= '</div>';
        }

        echo $html;
    }
    protected function _content_template() {

    }
}